# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .cancellation_details_item import CancellationDetailsItem


@JsonMap({})
class CancellationReason(BaseModel):
    """Possible keys \:
    * correctTeam1Id
    * correctTeam2Id
    * correctListedPitcher1
    * correctListedPitcher2
    * correctSpread
    * correctTotalPoints
    * correctTeam1TotalPoints
    * correctTeam2TotalPoints
    * correctTeam1Score
    * correctTeam2Score
    * correctTeam1TennisSetsScore
    * correctTeam2TennisSetsScore


    :param code: code
    :type code: str
    :param details: details, defaults to None
    :type details: List[CancellationDetailsItem], optional
    """

    def __init__(self, code: str, details: List[CancellationDetailsItem] = None):
        self.code = code
        if details is not None:
            self.details = self._define_list(details, CancellationDetailsItem)



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .special_bet_request import SpecialBetRequest


@JsonMap({})
class MultiBetRequestSpecialBetRequest(BaseModel):
    """MultiBetRequestSpecialBetRequest

    :param bets: The individual bets., defaults to None
    :type bets: List[SpecialBetRequest], optional
    """

    def __init__(self, bets: List[SpecialBetRequest] = None):
        if bets is not None:
            self.bets = self._define_list(bets, SpecialBetRequest)



# This file was generated by liblab | https://liblab.com/

from enum import Enum


class Betlist(Enum):
    """An enumeration representing different categories.

    :cvar SETTLED: "SETTLED"
    :vartype SETTLED: str
    :cvar RUNNING: "RUNNING"
    :vartype RUNNING: str
    :cvar ALL: "ALL"
    :vartype ALL: str
    """

    SETTLED = "SETTLED"
    RUNNING = "RUNNING"
    ALL = "ALL"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, Betlist._member_map_.values()))



# This file was generated by liblab | https://liblab.com/

from enum import Enum


class BetStatuses(Enum):
    """An enumeration representing different categories.

    :cvar WON: "WON"
    :vartype WON: str
    :cvar LOSE: "LOSE"
    :vartype LOSE: str
    :cvar CANCELLED: "CANCELLED"
    :vartype CANCELLED: str
    :cvar REFUNDED: "REFUNDED"
    :vartype REFUNDED: str
    :cvar NOT_ACCEPTED: "NOT_ACCEPTED"
    :vartype NOT_ACCEPTED: str
    :cvar ACCEPTED: "ACCEPTED"
    :vartype ACCEPTED: str
    :cvar PENDING_ACCEPTANCE: "PENDING_ACCEPTANCE"
    :vartype PENDING_ACCEPTANCE: str
    """

    WON = "WON"
    LOSE = "LOSE"
    CANCELLED = "CANCELLED"
    REFUNDED = "REFUNDED"
    NOT_ACCEPTED = "NOT_ACCEPTED"
    ACCEPTED = "ACCEPTED"
    PENDING_ACCEPTANCE = "PENDING_ACCEPTANCE"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, BetStatuses._member_map_.values()))



# This file was generated by liblab | https://liblab.com/

from enum import Enum
from .utils.json_map import JsonMap
from .base import BaseModel


class PlaceStraightBetResponseStatus(Enum):
    """An enumeration representing different categories.

    :cvar ACCEPTED: "ACCEPTED"
    :vartype ACCEPTED: str
    :cvar PENDING_ACCEPTANCE: "PENDING_ACCEPTANCE"
    :vartype PENDING_ACCEPTANCE: str
    :cvar PROCESSED_WITH_ERROR: "PROCESSED_WITH_ERROR"
    :vartype PROCESSED_WITH_ERROR: str
    """

    ACCEPTED = "ACCEPTED"
    PENDING_ACCEPTANCE = "PENDING_ACCEPTANCE"
    PROCESSED_WITH_ERROR = "PROCESSED_WITH_ERROR"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, PlaceStraightBetResponseStatus._member_map_.values())
        )


class PlaceStraightBetResponseErrorCode(Enum):
    """An enumeration representing different categories.

    :cvar ALL_BETTING_CLOSED: "ALL_BETTING_CLOSED"
    :vartype ALL_BETTING_CLOSED: str
    :cvar ALL_LIVE_BETTING_CLOSED: "ALL_LIVE_BETTING_CLOSED"
    :vartype ALL_LIVE_BETTING_CLOSED: str
    :cvar ABOVE_EVENT_MAX: "ABOVE_EVENT_MAX"
    :vartype ABOVE_EVENT_MAX: str
    :cvar ABOVE_MAX_BET_AMOUNT: "ABOVE_MAX_BET_AMOUNT"
    :vartype ABOVE_MAX_BET_AMOUNT: str
    :cvar BELOW_MIN_BET_AMOUNT: "BELOW_MIN_BET_AMOUNT"
    :vartype BELOW_MIN_BET_AMOUNT: str
    :cvar BLOCKED_BETTING: "BLOCKED_BETTING"
    :vartype BLOCKED_BETTING: str
    :cvar BLOCKED_CLIENT: "BLOCKED_CLIENT"
    :vartype BLOCKED_CLIENT: str
    :cvar INSUFFICIENT_FUNDS: "INSUFFICIENT_FUNDS"
    :vartype INSUFFICIENT_FUNDS: str
    :cvar INVALID_COUNTRY: "INVALID_COUNTRY"
    :vartype INVALID_COUNTRY: str
    :cvar INVALID_EVENT: "INVALID_EVENT"
    :vartype INVALID_EVENT: str
    :cvar INVALID_ODDS_FORMAT: "INVALID_ODDS_FORMAT"
    :vartype INVALID_ODDS_FORMAT: str
    :cvar LINE_CHANGED: "LINE_CHANGED"
    :vartype LINE_CHANGED: str
    :cvar LISTED_PITCHERS_SELECTION_ERROR: "LISTED_PITCHERS_SELECTION_ERROR"
    :vartype LISTED_PITCHERS_SELECTION_ERROR: str
    :cvar OFFLINE_EVENT: "OFFLINE_EVENT"
    :vartype OFFLINE_EVENT: str
    :cvar PAST_CUTOFFTIME: "PAST_CUTOFFTIME"
    :vartype PAST_CUTOFFTIME: str
    :cvar RED_CARDS_CHANGED: "RED_CARDS_CHANGED"
    :vartype RED_CARDS_CHANGED: str
    :cvar SCORE_CHANGED: "SCORE_CHANGED"
    :vartype SCORE_CHANGED: str
    :cvar TIME_RESTRICTION: "TIME_RESTRICTION"
    :vartype TIME_RESTRICTION: str
    :cvar DUPLICATED_REQUEST: "DUPLICATED_REQUEST"
    :vartype DUPLICATED_REQUEST: str
    :cvar INCOMPLETE_CUSTOMER_BETTING_PROFILE: "INCOMPLETE_CUSTOMER_BETTING_PROFILE"
    :vartype INCOMPLETE_CUSTOMER_BETTING_PROFILE: str
    :cvar INVALID_CUSTOMER_PROFILE: "INVALID_CUSTOMER_PROFILE"
    :vartype INVALID_CUSTOMER_PROFILE: str
    :cvar LIMITS_CONFIGURATION_ISSUE: "LIMITS_CONFIGURATION_ISSUE"
    :vartype LIMITS_CONFIGURATION_ISSUE: str
    :cvar RESPONSIBLE_BETTING_LOSS_LIMIT_EXCEEDED: "RESPONSIBLE_BETTING_LOSS_LIMIT_EXCEEDED"
    :vartype RESPONSIBLE_BETTING_LOSS_LIMIT_EXCEEDED: str
    :cvar RESPONSIBLE_BETTING_RISK_LIMIT_EXCEEDED: "RESPONSIBLE_BETTING_RISK_LIMIT_EXCEEDED"
    :vartype RESPONSIBLE_BETTING_RISK_LIMIT_EXCEEDED: str
    :cvar SYSTEM_ERROR_3: "SYSTEM_ERROR_3"
    :vartype SYSTEM_ERROR_3: str
    :cvar LICENCE_RESTRICTION_LIVE_BETTING_BLOCKED: "LICENCE_RESTRICTION_LIVE_BETTING_BLOCKED"
    :vartype LICENCE_RESTRICTION_LIVE_BETTING_BLOCKED: str
    :cvar BETTING_SUSPENDED: "BETTING_SUSPENDED"
    :vartype BETTING_SUSPENDED: str
    """

    ALL_BETTING_CLOSED = "ALL_BETTING_CLOSED"
    ALL_LIVE_BETTING_CLOSED = "ALL_LIVE_BETTING_CLOSED"
    ABOVE_EVENT_MAX = "ABOVE_EVENT_MAX"
    ABOVE_MAX_BET_AMOUNT = "ABOVE_MAX_BET_AMOUNT"
    BELOW_MIN_BET_AMOUNT = "BELOW_MIN_BET_AMOUNT"
    BLOCKED_BETTING = "BLOCKED_BETTING"
    BLOCKED_CLIENT = "BLOCKED_CLIENT"
    INSUFFICIENT_FUNDS = "INSUFFICIENT_FUNDS"
    INVALID_COUNTRY = "INVALID_COUNTRY"
    INVALID_EVENT = "INVALID_EVENT"
    INVALID_ODDS_FORMAT = "INVALID_ODDS_FORMAT"
    LINE_CHANGED = "LINE_CHANGED"
    LISTED_PITCHERS_SELECTION_ERROR = "LISTED_PITCHERS_SELECTION_ERROR"
    OFFLINE_EVENT = "OFFLINE_EVENT"
    PAST_CUTOFFTIME = "PAST_CUTOFFTIME"
    RED_CARDS_CHANGED = "RED_CARDS_CHANGED"
    SCORE_CHANGED = "SCORE_CHANGED"
    TIME_RESTRICTION = "TIME_RESTRICTION"
    DUPLICATED_REQUEST = "DUPLICATED_REQUEST"
    INCOMPLETE_CUSTOMER_BETTING_PROFILE = "INCOMPLETE_CUSTOMER_BETTING_PROFILE"
    INVALID_CUSTOMER_PROFILE = "INVALID_CUSTOMER_PROFILE"
    LIMITS_CONFIGURATION_ISSUE = "LIMITS_CONFIGURATION_ISSUE"
    RESPONSIBLE_BETTING_LOSS_LIMIT_EXCEEDED = "RESPONSIBLE_BETTING_LOSS_LIMIT_EXCEEDED"
    RESPONSIBLE_BETTING_RISK_LIMIT_EXCEEDED = "RESPONSIBLE_BETTING_RISK_LIMIT_EXCEEDED"
    SYSTEM_ERROR_3 = "SYSTEM_ERROR_3"
    LICENCE_RESTRICTION_LIVE_BETTING_BLOCKED = (
        "LICENCE_RESTRICTION_LIVE_BETTING_BLOCKED"
    )
    BETTING_SUSPENDED = "BETTING_SUSPENDED"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value,
                PlaceStraightBetResponseErrorCode._member_map_.values(),
            )
        )


@JsonMap(
    {
        "error_code": "errorCode",
        "unique_request_id": "uniqueRequestId",
        "bet_id": "betId",
        "better_line_was_accepted": "betterLineWasAccepted",
    }
)
class PlaceStraightBetResponse(BaseModel):
    """PlaceStraightBetResponse

    :param status: Status of the response., defaults to None
    :type status: PlaceStraightBetResponseStatus, optional
    :param error_code: If Status is PROCESSED_WITH_ERROR, errorCode will be in the response. <br><br>ALL_BETTING_CLOSED = Betting is not allowed at this moment. This may happen during system maintenance,  <br>ALL_LIVE_BETTING_CLOSED = Live betting is not allowed at this moment. This may happen during system maintenance,  <br>ABOVE_EVENT_MAX = Bet cannot be placed because client exceeded allowed maximum of risk on a line,  <br>ABOVE_MAX_BET_AMOUNT = Stake is above allowed maximum amount,   <br>BELOW_MIN_BET_AMOUNT = Stake is below allowed minimum amount,  <br>BLOCKED_BETTING = Betting is suspended for the client,  <br>BLOCKED_CLIENT = Client is no longer active,   <br>INSUFFICIENT_FUNDS = Bet is submitted by a client with insufficient funds,  <br>INVALID_COUNTRY = Client country is not allowed for betting,  <br>INVALID_EVENT = Invalid eventid,  <br>INVALID_ODDS_FORMAT = If a bet was submitted with the odds format that is not allowed for the client,  <br>LINE_CHANGED = Bet is submitted on a line that has changed,  <br>OFFLINE_EVENT = Bet is submitted on an event that is offline or the submitted line is not offered at the moment due to points/handicap change or the submitted bet type is just not offered at the moment,  <br>PAST_CUTOFFTIME = Bet is submitted on a game after the betting cutoff time,  <br>RED_CARDS_CHANGED = Bet is submitted on a live soccer event with changed red card count,  <br>SCORE_CHANGED = Bet is submitted on a live soccer event with changed score,  <br>TIME_RESTRICTION = Bet is submitted within too short of a period from the same bet previously placed by a client,  <br>DUPLICATED_REQUEST = Request with the same uniqueRequestId was already processed. Please set the new value if you still want the request to be processed,  <br>INCOMPLETE_CUSTOMER_BETTING_PROFILE = System configuration issue,  <br>INVALID_CUSTOMER_PROFILE = System configuration issue,  <br>LIMITS_CONFIGURATION_ISSUE = System configuration issue,  <br>RESPONSIBLE_BETTING_LOSS_LIMIT_EXCEEDED = Client has reached his total loss limit,  <br>RESPONSIBLE_BETTING_RISK_LIMIT_EXCEEDED = Client has reached his total risk limit,  <br>SYSTEM_ERROR_3 = Unexpected error,  <br>LICENCE_RESTRICTION_LIVE_BETTING_BLOCKED - Live betting blocked due to licence restrictions, <br>BETTING_SUSPENDED - Due to anomalous market circumstances bets are not currently being accepted on this line. Try again with next LineId.<br>, defaults to None
    :type error_code: PlaceStraightBetResponseErrorCode, optional
    :param unique_request_id: Echo of the uniqueRequestId from the request., defaults to None
    :type unique_request_id: str, optional
    :param bet_id: Bet identification. Populated in case of accepted bet., defaults to None
    :type bet_id: int, optional
    :param win: Win amount. Populated in case of accepted bet., defaults to None
    :type win: float, optional
    :param risk: Risk amount.  Populated in case of accepted bet., defaults to None
    :type risk: float, optional
    :param price: Bet price. Populated in case of accepted bet., defaults to None
    :type price: float, optional
    :param better_line_was_accepted: Whether or not the bet was accepted on the line that changed in favour of client. This can be true only if `acceptBetterLine` in the Place Bet request is set to TRUE., defaults to None
    :type better_line_was_accepted: bool, optional
    """

    def __init__(
        self,
        status: PlaceStraightBetResponseStatus = None,
        error_code: PlaceStraightBetResponseErrorCode = None,
        unique_request_id: str = None,
        bet_id: int = None,
        win: float = None,
        risk: float = None,
        price: float = None,
        better_line_was_accepted: bool = None,
    ):
        if status is not None:
            self.status = self._enum_matching(
                status, PlaceStraightBetResponseStatus.list(), "status"
            )
        if error_code is not None:
            self.error_code = self._enum_matching(
                error_code, PlaceStraightBetResponseErrorCode.list(), "error_code"
            )
        if unique_request_id is not None:
            self.unique_request_id = unique_request_id
        if bet_id is not None:
            self.bet_id = bet_id
        if win is not None:
            self.win = win
        if risk is not None:
            self.risk = risk
        if price is not None:
            self.price = price
        if better_line_was_accepted is not None:
            self.better_line_was_accepted = better_line_was_accepted



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class CancellationDetailsItem(BaseModel):
    """CancellationDetailsItem

    :param key: key, defaults to None
    :type key: str, optional
    :param value: value, defaults to None
    :type value: str, optional
    """

    def __init__(self, key: str = None, value: str = None):
        if key is not None:
            self.key = key
        if value is not None:
            self.value = value



# This file was generated by liblab | https://liblab.com/

from .place_bet_request import PlaceBetRequest
from .place_straight_bet_response import PlaceStraightBetResponse
from .place_parlay_bet_request import PlaceParlayBetRequest
from .place_parlay_bet_response import PlaceParlayBetResponse
from .place_teaser_bet_request import PlaceTeaserBetRequest
from .place_teaser_bet_response import PlaceTeaserBetResponse
from .multi_bet_request_special_bet_request import MultiBetRequestSpecialBetRequest
from .multi_bet_response_special_bet_response import MultiBetResponseSpecialBetResponse
from .get_bets_by_type_response_v4 import GetBetsByTypeResponseV4
from .betlist import Betlist
from .bet_statuses import BetStatuses
from .sort_dir import SortDir
from .bets_get_bets_by_type_v4_bet_type import BetsGetBetsByTypeV4BetType
from .betting_status_response import BettingStatusResponse
from .odds_format import OddsFormat
from .parlay_leg_request import ParlayLegRequest
from .round_robin_option_with_odds import RoundRobinOptionWithOdds
from .parlay_leg_response import ParlayLegResponse
from .teaser_bet_leg import TeaserBetLeg
from .place_teaser_bet_leg_response import PlaceTeaserBetLegResponse
from .special_bet_request import SpecialBetRequest
from .special_bet_response import SpecialBetResponse
from .straight_bet_v4 import StraightBetV4
from .parlay_bet import ParlayBet
from .teaser_bet import TeaserBet
from .special_bet import SpecialBet
from .manual_bet import ManualBet
from .cancellation_reason import CancellationReason
from .cancellation_details_item import CancellationDetailsItem
from .parlay_leg import ParlayLeg
from .teaser_leg import TeaserLeg



# This file was generated by liblab | https://liblab.com/

from enum import Enum
from .utils.json_map import JsonMap
from .base import BaseModel


class ManualBetBetStatus(Enum):
    """An enumeration representing different categories.

    :cvar ACCEPTED: "ACCEPTED"
    :vartype ACCEPTED: str
    :cvar CANCELLED: "CANCELLED"
    :vartype CANCELLED: str
    :cvar LOSE: "LOSE"
    :vartype LOSE: str
    :cvar REFUNDED: "REFUNDED"
    :vartype REFUNDED: str
    :cvar WON: "WON"
    :vartype WON: str
    """

    ACCEPTED = "ACCEPTED"
    CANCELLED = "CANCELLED"
    LOSE = "LOSE"
    REFUNDED = "REFUNDED"
    WON = "WON"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, ManualBetBetStatus._member_map_.values()))


@JsonMap(
    {
        "bet_id": "betId",
        "wager_number": "wagerNumber",
        "placed_at": "placedAt",
        "bet_status": "betStatus",
        "bet_type": "betType",
        "win_loss": "winLoss",
        "update_sequence": "updateSequence",
        "reference_bet_id": "referenceBetId",
    }
)
class ManualBet(BaseModel):
    """ManualBet

    :param bet_id: Bet identification
    :type bet_id: int
    :param wager_number: Wager identification. All bets placed thru the API will have value 1. Website Classic view supports multiple contest(special) bets placement in the same bet slip in that case the bet would have appropriate wager number, as well as all round robin parlay bets.
    :type wager_number: int
    :param placed_at: Date time when the bet was placed.
    :type placed_at: str
    :param bet_status: Bet Status. <br><br>ACCEPTED = Bet was accepted,  <br>CANCELLED = Bet is cancelled as per Pinnacle betting rules,  <br>LOSE = The bet is settled as lose,  <br>REFUNDED = When an event is cancelled or when the bet is settled as push, the bet will have REFUNDED status,  <br>WON = The bet is settled as won <br>
    :type bet_status: ManualBetBetStatus
    :param bet_type: bet_type
    :type bet_type: str
    :param win: Win amount.
    :type win: float
    :param risk: Risk amount.
    :type risk: float
    :param win_loss: Win-Loss for settled bets., defaults to None
    :type win_loss: float, optional
    :param update_sequence: Update Sequence
    :type update_sequence: int
    :param description: Manual bet description.
    :type description: str
    :param reference_bet_id: Referenced original bet id., defaults to None
    :type reference_bet_id: int, optional
    """

    def __init__(
        self,
        bet_id: int,
        wager_number: int,
        placed_at: str,
        bet_status: ManualBetBetStatus,
        bet_type: str,
        win: float,
        risk: float,
        update_sequence: int,
        description: str,
        win_loss: float = None,
        reference_bet_id: int = None,
    ):
        self.bet_id = bet_id
        self.wager_number = wager_number
        self.placed_at = placed_at
        self.bet_status = self._enum_matching(
            bet_status, ManualBetBetStatus.list(), "bet_status"
        )
        self.bet_type = bet_type
        self.win = win
        self.risk = risk
        if win_loss is not None:
            self.win_loss = win_loss
        self.update_sequence = update_sequence
        self.description = description
        if reference_bet_id is not None:
            self.reference_bet_id = reference_bet_id



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from enum import Enum
from .utils.json_map import JsonMap
from .base import BaseModel
from .cancellation_reason import CancellationReason


class ParlayLegLegBetType(Enum):
    """An enumeration representing different categories.

    :cvar MONEYLINE: "MONEYLINE"
    :vartype MONEYLINE: str
    :cvar SPREAD: "SPREAD"
    :vartype SPREAD: str
    :cvar TOTAL_POINTS: "TOTAL_POINTS"
    :vartype TOTAL_POINTS: str
    """

    MONEYLINE = "MONEYLINE"
    SPREAD = "SPREAD"
    TOTAL_POINTS = "TOTAL_POINTS"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, ParlayLegLegBetType._member_map_.values()))


class ParlayLegLegBetStatus(Enum):
    """An enumeration representing different categories.

    :cvar CANCELLED: "CANCELLED"
    :vartype CANCELLED: str
    :cvar LOST: "LOST"
    :vartype LOST: str
    :cvar PUSHED: "PUSHED"
    :vartype PUSHED: str
    :cvar REFUNDED: "REFUNDED"
    :vartype REFUNDED: str
    :cvar WON: "WON"
    :vartype WON: str
    :cvar ACCEPTED: "ACCEPTED"
    :vartype ACCEPTED: str
    :cvar HALF_WON_HALF_PUSHED: "HALF_WON_HALF_PUSHED"
    :vartype HALF_WON_HALF_PUSHED: str
    :cvar HALF_LOST_HALF_PUSHED: "HALF_LOST_HALF_PUSHED"
    :vartype HALF_LOST_HALF_PUSHED: str
    """

    CANCELLED = "CANCELLED"
    LOST = "LOST"
    PUSHED = "PUSHED"
    REFUNDED = "REFUNDED"
    WON = "WON"
    ACCEPTED = "ACCEPTED"
    HALF_WON_HALF_PUSHED = "HALF_WON_HALF_PUSHED"
    HALF_LOST_HALF_PUSHED = "HALF_LOST_HALF_PUSHED"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, ParlayLegLegBetStatus._member_map_.values()))


class ParlayLegSide(Enum):
    """An enumeration representing different categories.

    :cvar OVER: "OVER"
    :vartype OVER: str
    :cvar UNDER: "UNDER"
    :vartype UNDER: str
    """

    OVER = "OVER"
    UNDER = "UNDER"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, ParlayLegSide._member_map_.values()))


@JsonMap(
    {
        "sport_id": "sportId",
        "leg_bet_type": "legBetType",
        "leg_bet_status": "legBetStatus",
        "league_id": "leagueId",
        "event_id": "eventId",
        "event_start_time": "eventStartTime",
        "team_name": "teamName",
        "period_number": "periodNumber",
        "ft_team1_score": "ftTeam1Score",
        "ft_team2_score": "ftTeam2Score",
        "p_team1_score": "pTeam1Score",
        "p_team2_score": "pTeam2Score",
        "cancellation_reason": "cancellationReason",
    }
)
class ParlayLeg(BaseModel):
    """ParlayLeg

    :param sport_id: sport_id, defaults to None
    :type sport_id: int, optional
    :param leg_bet_type: Parlay leg type., defaults to None
    :type leg_bet_type: ParlayLegLegBetType, optional
    :param leg_bet_status: Parlay Leg status.<br>CANCELLED = The leg is canceled- the stake on this leg will be transferred to the next one. In this case the leg will be ignored when calculating the winLoss.<br>LOST = The leg is a loss or a push-lose. When Push-lose happens, the half of the stake on the leg will be pushed to the next leg, and the other half will be a lose. This can happen only when the leg is placed on a quarter points handicap.  <br>PUSHED = The leg is a push - the stake on this leg will be transferred to the next one. In this case the leg will be ignored when calculating the winLoss.  <br>REFUNDED = The leg is refunded - the stake on this leg will be transferred to the next one. In this case the leg will be ignored when calculating the winLoss.  <br>WON = The leg is a won or a push-won. When Push-won happens, the half of the stake on the leg will be pushed to the next leg, and the other half is won. This can happen only when the leg is placed on a quarter points handicap.<br>HALF_WON_HALF_PUSHED = The bet is settled as half won half pushed. Only for asian handicap legs.<br>HALF_LOST_HALF_PUSHED =  The bet is settled as half lost half pushed. Only for asian handicap legs. <br>, defaults to None
    :type leg_bet_status: ParlayLegLegBetStatus, optional
    :param league_id: league_id, defaults to None
    :type league_id: int, optional
    :param event_id: event_id, defaults to None
    :type event_id: int, optional
    :param event_start_time: Date time when the event starts., defaults to None
    :type event_start_time: str, optional
    :param handicap: handicap, defaults to None
    :type handicap: float, optional
    :param price: price, defaults to None
    :type price: float, optional
    :param team_name: team_name, defaults to None
    :type team_name: str, optional
    :param side: Side type., defaults to None
    :type side: ParlayLegSide, optional
    :param team1: Wellington Phoenix, defaults to None
    :type team1: str, optional
    :param team2: Adelaide United, defaults to None
    :type team2: str, optional
    :param period_number: period_number, defaults to None
    :type period_number: int, optional
    :param ft_team1_score: Full time team 1 score, defaults to None
    :type ft_team1_score: float, optional
    :param ft_team2_score: Full time team 2 score, defaults to None
    :type ft_team2_score: float, optional
    :param p_team1_score: End of period team 1 score. If the bet was placed on Game period (periodNumber =0) , this will be null, defaults to None
    :type p_team1_score: float, optional
    :param p_team2_score: End of period team 2 score. If the bet was placed on Game period (periodNumber =0) , this will be null, defaults to None
    :type p_team2_score: float, optional
    :param cancellation_reason: Possible keys \:  <br>* correctTeam1Id<br>* correctTeam2Id<br>* correctListedPitcher1<br>* correctListedPitcher2<br>* correctSpread<br>* correctTotalPoints<br>* correctTeam1TotalPoints<br>* correctTeam2TotalPoints<br>* correctTeam1Score<br>* correctTeam2Score<br>* correctTeam1TennisSetsScore<br>* correctTeam2TennisSetsScore<br>, defaults to None
    :type cancellation_reason: CancellationReason, optional
    """

    def __init__(
        self,
        sport_id: int = None,
        leg_bet_type: ParlayLegLegBetType = None,
        leg_bet_status: ParlayLegLegBetStatus = None,
        league_id: int = None,
        event_id: int = None,
        event_start_time: str = None,
        handicap: float = None,
        price: float = None,
        team_name: str = None,
        side: ParlayLegSide = None,
        team1: str = None,
        team2: str = None,
        period_number: int = None,
        ft_team1_score: float = None,
        ft_team2_score: float = None,
        p_team1_score: float = None,
        p_team2_score: float = None,
        cancellation_reason: CancellationReason = None,
    ):
        if sport_id is not None:
            self.sport_id = sport_id
        if leg_bet_type is not None:
            self.leg_bet_type = self._enum_matching(
                leg_bet_type, ParlayLegLegBetType.list(), "leg_bet_type"
            )
        if leg_bet_status is not None:
            self.leg_bet_status = self._enum_matching(
                leg_bet_status, ParlayLegLegBetStatus.list(), "leg_bet_status"
            )
        if league_id is not None:
            self.league_id = league_id
        if event_id is not None:
            self.event_id = event_id
        if event_start_time is not None:
            self.event_start_time = event_start_time
        if handicap is not None:
            self.handicap = handicap
        if price is not None:
            self.price = price
        if team_name is not None:
            self.team_name = team_name
        if side is not None:
            self.side = self._enum_matching(side, ParlayLegSide.list(), "side")
        if team1 is not None:
            self.team1 = team1
        if team2 is not None:
            self.team2 = team2
        if period_number is not None:
            self.period_number = period_number
        if ft_team1_score is not None:
            self.ft_team1_score = ft_team1_score
        if ft_team2_score is not None:
            self.ft_team2_score = ft_team2_score
        if p_team1_score is not None:
            self.p_team1_score = p_team1_score
        if p_team2_score is not None:
            self.p_team2_score = p_team2_score
        if cancellation_reason is not None:
            self.cancellation_reason = self._define_object(
                cancellation_reason, CancellationReason
            )



# This file was generated by liblab | https://liblab.com/

from enum import Enum
from .utils.json_map import JsonMap
from .base import BaseModel


class TeaserBetLegBetType(Enum):
    """An enumeration representing different categories.

    :cvar SPREAD: "SPREAD"
    :vartype SPREAD: str
    :cvar TOTAL_POINTS: "TOTAL_POINTS"
    :vartype TOTAL_POINTS: str
    """

    SPREAD = "SPREAD"
    TOTAL_POINTS = "TOTAL_POINTS"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, TeaserBetLegBetType._member_map_.values()))


class TeaserBetLegSide(Enum):
    """An enumeration representing different categories.

    :cvar OVER: "OVER"
    :vartype OVER: str
    :cvar UNDER: "UNDER"
    :vartype UNDER: str
    """

    OVER = "OVER"
    UNDER = "UNDER"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, TeaserBetLegSide._member_map_.values()))


@JsonMap(
    {
        "leg_id": "legId",
        "bet_type": "betType",
        "line_id": "lineId",
        "event_id": "eventId",
    }
)
class TeaserBetLeg(BaseModel):
    """TeaserBetLeg

    :param leg_id: Client generated GUID for uniquely identifying the leg., defaults to None
    :type leg_id: str, optional
    :param bet_type: Leg bet type can be SPREAD or TOTAL_POINTS , defaults to None
    :type bet_type: TeaserBetLegBetType, optional
    :param line_id: Unique identifier., defaults to None
    :type line_id: int, optional
    :param event_id: Unique identifier., defaults to None
    :type event_id: int, optional
    :param team: Team being bet on for a spread line., defaults to None
    :type team: str, optional
    :param side: Chosen side type. This is needed only for TOTAL_POINTS bet type., defaults to None
    :type side: TeaserBetLegSide, optional
    """

    def __init__(
        self,
        leg_id: str = None,
        bet_type: TeaserBetLegBetType = None,
        line_id: int = None,
        event_id: int = None,
        team: str = None,
        side: TeaserBetLegSide = None,
    ):
        if leg_id is not None:
            self.leg_id = leg_id
        if bet_type is not None:
            self.bet_type = self._enum_matching(
                bet_type, TeaserBetLegBetType.list(), "bet_type"
            )
        if line_id is not None:
            self.line_id = line_id
        if event_id is not None:
            self.event_id = event_id
        if team is not None:
            self.team = team
        if side is not None:
            self.side = self._enum_matching(side, TeaserBetLegSide.list(), "side")



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from enum import Enum
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .round_robin_option_with_odds import RoundRobinOptionWithOdds
from .parlay_leg_response import ParlayLegResponse


class PlaceParlayBetResponseStatus(Enum):
    """An enumeration representing different categories.

    :cvar ACCEPTED: "ACCEPTED"
    :vartype ACCEPTED: str
    :cvar PROCESSED_WITH_ERROR: "PROCESSED_WITH_ERROR"
    :vartype PROCESSED_WITH_ERROR: str
    """

    ACCEPTED = "ACCEPTED"
    PROCESSED_WITH_ERROR = "PROCESSED_WITH_ERROR"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, PlaceParlayBetResponseStatus._member_map_.values())
        )


class PlaceParlayBetResponseErrorCode(Enum):
    """An enumeration representing different categories.

    :cvar ABOVE_MAX_BET_AMOUNT: "ABOVE_MAX_BET_AMOUNT"
    :vartype ABOVE_MAX_BET_AMOUNT: str
    :cvar ALL_BETTING_CLOSED: "ALL_BETTING_CLOSED"
    :vartype ALL_BETTING_CLOSED: str
    :cvar BELOW_MIN_BET_AMOUNT: "BELOW_MIN_BET_AMOUNT"
    :vartype BELOW_MIN_BET_AMOUNT: str
    :cvar BLOCKED_BETTING: "BLOCKED_BETTING"
    :vartype BLOCKED_BETTING: str
    :cvar BLOCKED_CLIENT: "BLOCKED_CLIENT"
    :vartype BLOCKED_CLIENT: str
    :cvar INSUFFICIENT_FUNDS: "INSUFFICIENT_FUNDS"
    :vartype INSUFFICIENT_FUNDS: str
    :cvar INVALID_COUNTRY: "INVALID_COUNTRY"
    :vartype INVALID_COUNTRY: str
    :cvar INVALID_LEGS: "INVALID_LEGS"
    :vartype INVALID_LEGS: str
    :cvar INVALID_ODDS_FORMAT: "INVALID_ODDS_FORMAT"
    :vartype INVALID_ODDS_FORMAT: str
    :cvar INVALID_ROUND_ROBIN_OPTIONS: "INVALID_ROUND_ROBIN_OPTIONS"
    :vartype INVALID_ROUND_ROBIN_OPTIONS: str
    :cvar ROUND_ROBIN_DISALLOWED: "ROUND_ROBIN_DISALLOWED"
    :vartype ROUND_ROBIN_DISALLOWED: str
    :cvar TOO_MANY_LEGS: "TOO_MANY_LEGS"
    :vartype TOO_MANY_LEGS: str
    :cvar TOO_FEW_LEGS: "TOO_FEW_LEGS"
    :vartype TOO_FEW_LEGS: str
    :cvar RESPONSIBLE_BETTING_RISK_LIMIT_EXCEEDED: "RESPONSIBLE_BETTING_RISK_LIMIT_EXCEEDED"
    :vartype RESPONSIBLE_BETTING_RISK_LIMIT_EXCEEDED: str
    :cvar RESPONSIBLE_BETTING_LOSS_LIMIT_EXCEEDED: "RESPONSIBLE_BETTING_LOSS_LIMIT_EXCEEDED"
    :vartype RESPONSIBLE_BETTING_LOSS_LIMIT_EXCEEDED: str
    :cvar INVALID_REQUEST: "INVALID_REQUEST"
    :vartype INVALID_REQUEST: str
    :cvar DUPLICATED_REQUEST: "DUPLICATED_REQUEST"
    :vartype DUPLICATED_REQUEST: str
    :cvar SYSTEM_ERROR_3: "SYSTEM_ERROR_3"
    :vartype SYSTEM_ERROR_3: str
    """

    ABOVE_MAX_BET_AMOUNT = "ABOVE_MAX_BET_AMOUNT"
    ALL_BETTING_CLOSED = "ALL_BETTING_CLOSED"
    BELOW_MIN_BET_AMOUNT = "BELOW_MIN_BET_AMOUNT"
    BLOCKED_BETTING = "BLOCKED_BETTING"
    BLOCKED_CLIENT = "BLOCKED_CLIENT"
    INSUFFICIENT_FUNDS = "INSUFFICIENT_FUNDS"
    INVALID_COUNTRY = "INVALID_COUNTRY"
    INVALID_LEGS = "INVALID_LEGS"
    INVALID_ODDS_FORMAT = "INVALID_ODDS_FORMAT"
    INVALID_ROUND_ROBIN_OPTIONS = "INVALID_ROUND_ROBIN_OPTIONS"
    ROUND_ROBIN_DISALLOWED = "ROUND_ROBIN_DISALLOWED"
    TOO_MANY_LEGS = "TOO_MANY_LEGS"
    TOO_FEW_LEGS = "TOO_FEW_LEGS"
    RESPONSIBLE_BETTING_RISK_LIMIT_EXCEEDED = "RESPONSIBLE_BETTING_RISK_LIMIT_EXCEEDED"
    RESPONSIBLE_BETTING_LOSS_LIMIT_EXCEEDED = "RESPONSIBLE_BETTING_LOSS_LIMIT_EXCEEDED"
    INVALID_REQUEST = "INVALID_REQUEST"
    DUPLICATED_REQUEST = "DUPLICATED_REQUEST"
    SYSTEM_ERROR_3 = "SYSTEM_ERROR_3"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value, PlaceParlayBetResponseErrorCode._member_map_.values()
            )
        )


@JsonMap(
    {
        "error_code": "errorCode",
        "bet_id": "betId",
        "unique_request_id": "uniqueRequestId",
        "round_robin_option_with_odds": "roundRobinOptionWithOdds",
        "max_risk_stake": "maxRiskStake",
        "min_risk_stake": "minRiskStake",
        "valid_legs": "validLegs",
        "invalid_legs": "invalidLegs",
    }
)
class PlaceParlayBetResponse(BaseModel):
    """PlaceParlayBetResponse

    :param status: Status of the response., defaults to None
    :type status: PlaceParlayBetResponseStatus, optional
    :param error_code: When Status is PROCESSED_WITH_ERROR, provides a code indicating the specific problem.<br><br><br>ABOVE_MAX_BET_AMOUNT = Stake is above allowed maximum amount,  <br>ALL_BETTING_CLOSED = Betting is not allowed at this moment,  <br>BELOW_MIN_BET_AMOUNT = Stake is below allowed minimum amount,  <br>BLOCKED_BETTING = Betting is suspended for the client,   <br>BLOCKED_CLIENT = Client is no longer active,  <br>INSUFFICIENT_FUNDS = Bet is submitted by a client with insufficient funds,  <br>INVALID_COUNTRY = Client country is not allowed for betting,  <br>INVALID_LEGS = One or more legs are invalid,  <br>INVALID_ODDS_FORMAT = If a bet was submitted with the odds format that is not allowed for the client,  <br>INVALID_ROUND_ROBIN_OPTIONS = Round robin options are invalid (i.e. does not match with number of legs),  <br>ROUND_ROBIN_DISALLOWED = Round robin is disallowed for one of the leagues,  <br>TOO_MANY_LEGS = Maximum of 10 legs can be specified,  <br>TOO_FEW_LEGS = At least 2 legs are required for Parlay,  <br>RESPONSIBLE_BETTING_LOSS_LIMIT_EXCEEDED = Client has reached his total loss limit,  <br>RESPONSIBLE_BETTING_RISK_LIMIT_EXCEEDED = Client has reached his total risk limit,  <br>INVALID_REQUEST = Request has invalid parameters,  <br>DUPLICATED_REQUEST = Request with the same uniqueRequestId was already processed. Please set the new value if you still want the request to be processed,  <br>SYSTEM_ERROR_3 = Unexpected error <br>, defaults to None
    :type error_code: PlaceParlayBetResponseErrorCode, optional
    :param bet_id: Id of a newly created bet., defaults to None
    :type bet_id: int, optional
    :param unique_request_id: Unique identifier provided in the request., defaults to None
    :type unique_request_id: str, optional
    :param round_robin_option_with_odds: Provides array with all acceptable Round Robin options with parlay odds for that option., defaults to None
    :type round_robin_option_with_odds: List[RoundRobinOptionWithOdds], optional
    :param max_risk_stake: Maximum stake amount, defaults to None
    :type max_risk_stake: float, optional
    :param min_risk_stake: Minimum stake amount, defaults to None
    :type min_risk_stake: float, optional
    :param valid_legs: Collection of valid legs (format described below). Can be empty if no valid legs found., defaults to None
    :type valid_legs: List[ParlayLegResponse], optional
    :param invalid_legs: The collection of legs that resulted in error (format described below). Can be empty if no invalid legs found., defaults to None
    :type invalid_legs: List[ParlayLegResponse], optional
    """

    def __init__(
        self,
        status: PlaceParlayBetResponseStatus = None,
        error_code: PlaceParlayBetResponseErrorCode = None,
        bet_id: int = None,
        unique_request_id: str = None,
        round_robin_option_with_odds: List[RoundRobinOptionWithOdds] = None,
        max_risk_stake: float = None,
        min_risk_stake: float = None,
        valid_legs: List[ParlayLegResponse] = None,
        invalid_legs: List[ParlayLegResponse] = None,
    ):
        if status is not None:
            self.status = self._enum_matching(
                status, PlaceParlayBetResponseStatus.list(), "status"
            )
        if error_code is not None:
            self.error_code = self._enum_matching(
                error_code, PlaceParlayBetResponseErrorCode.list(), "error_code"
            )
        if bet_id is not None:
            self.bet_id = bet_id
        if unique_request_id is not None:
            self.unique_request_id = unique_request_id
        if round_robin_option_with_odds is not None:
            self.round_robin_option_with_odds = self._define_list(
                round_robin_option_with_odds, RoundRobinOptionWithOdds
            )
        if max_risk_stake is not None:
            self.max_risk_stake = max_risk_stake
        if min_risk_stake is not None:
            self.min_risk_stake = min_risk_stake
        if valid_legs is not None:
            self.valid_legs = self._define_list(valid_legs, ParlayLegResponse)
        if invalid_legs is not None:
            self.invalid_legs = self._define_list(invalid_legs, ParlayLegResponse)



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from enum import Enum
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .odds_format import OddsFormat
from .cancellation_reason import CancellationReason
from .parlay_leg import ParlayLeg


class ParlayBetBetStatus(Enum):
    """An enumeration representing different categories.

    :cvar ACCEPTED: "ACCEPTED"
    :vartype ACCEPTED: str
    :cvar CANCELLED: "CANCELLED"
    :vartype CANCELLED: str
    :cvar LOST: "LOST"
    :vartype LOST: str
    :cvar PENDING_ACCEPTANCE: "PENDING_ACCEPTANCE"
    :vartype PENDING_ACCEPTANCE: str
    :cvar REFUNDED: "REFUNDED"
    :vartype REFUNDED: str
    :cvar NOT_ACCEPTED: "NOT_ACCEPTED"
    :vartype NOT_ACCEPTED: str
    :cvar WON: "WON"
    :vartype WON: str
    :cvar PARTIAL_WON: "PARTIAL_WON"
    :vartype PARTIAL_WON: str
    :cvar PARTIAL_LOST: "PARTIAL_LOST"
    :vartype PARTIAL_LOST: str
    """

    ACCEPTED = "ACCEPTED"
    CANCELLED = "CANCELLED"
    LOST = "LOST"
    PENDING_ACCEPTANCE = "PENDING_ACCEPTANCE"
    REFUNDED = "REFUNDED"
    NOT_ACCEPTED = "NOT_ACCEPTED"
    WON = "WON"
    PARTIAL_WON = "PARTIAL_WON"
    PARTIAL_LOST = "PARTIAL_LOST"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, ParlayBetBetStatus._member_map_.values()))


@JsonMap(
    {
        "bet_id": "betId",
        "unique_request_id": "uniqueRequestId",
        "wager_number": "wagerNumber",
        "bet_status": "betStatus",
        "bet_type": "betType",
        "win_loss": "winLoss",
        "odds_format": "oddsFormat",
        "customer_commission": "customerCommission",
        "cancellation_reason": "cancellationReason",
        "update_sequence": "updateSequence",
        "final_price": "finalPrice",
    }
)
class ParlayBet(BaseModel):
    """ParlayBet

    :param bet_id: Bet identification
    :type bet_id: int
    :param unique_request_id: Unique Request Id, defaults to None
    :type unique_request_id: str, optional
    :param wager_number: Wager identification. All bets placed thru the API will have value 1. Website Classic view supports multiple contest(special) bets placement in the same bet slip in that case the bet would have appropriate wager number, as well as all round robin parlay bets.
    :type wager_number: int
    :param bet_status: Bet Status. <br><br>ACCEPTED = Bet was accepted.  <br>CANCELLED = Bet is cancelled as per Pinnacle betting rules.  <br>LOST = The bet is settled as lose.  <br>PENDING_ACCEPTANCE = This status is reserved only for live bets. If a live bet is placed during danger zone or live delay is applied, it will be in PENDING_ACCEPTANCE , otherwise in ACCEPTED status. From this status bet can go to ACCEPTED or REJECTED status.  <br>REFUNDED = When an event is cancelled or when the bet is settled as push, the bet will have REFUNDED status.  <br>NOT_ACCEPTED = Bet was not accepted. Bet can be in this status only if it was previously in PENDING_ACCEPTANCE status.  <br>WON = The bet is settled as won.  <br>PARTIAL_WON  - If gross payout is greater than the  stake. Only for parlays with the asian handicap legs.  <br>PARTIAL_LOST  - If gross payout is less or equal to the stake. Only for parlays with the asian handicap legs.<br>
    :type bet_status: ParlayBetBetStatus
    :param bet_type: bet_type
    :type bet_type: str
    :param win: Win amount.
    :type win: float
    :param risk: Risk amount.
    :type risk: float
    :param win_loss: Win-Loss for settled bets., defaults to None
    :type win_loss: float, optional
    :param odds_format: Bet odds format.  <br>AMERICAN = American odds format,  <br>DECIMAL = Decimal (European) odds format,  <br>HONGKONG = Hong Kong odds format,  <br>INDONESIAN = Indonesian odds format,  <br>MALAY = Malaysian odds format <br>
    :type odds_format: OddsFormat
    :param customer_commission: Client’s commission on the bet., defaults to None
    :type customer_commission: float, optional
    :param cancellation_reason: Possible keys \:  <br>* correctTeam1Id<br>* correctTeam2Id<br>* correctListedPitcher1<br>* correctListedPitcher2<br>* correctSpread<br>* correctTotalPoints<br>* correctTeam1TotalPoints<br>* correctTeam2TotalPoints<br>* correctTeam1Score<br>* correctTeam2Score<br>* correctTeam1TennisSetsScore<br>* correctTeam2TennisSetsScore<br>, defaults to None
    :type cancellation_reason: CancellationReason, optional
    :param update_sequence: Update Sequence
    :type update_sequence: int
    :param legs: legs
    :type legs: List[ParlayLeg]
    :param price: price, defaults to None
    :type price: float, optional
    :param final_price: Only for settled parlay. Final price may differ in case leg was cancelled or half won, defaults to None
    :type final_price: float, optional
    """

    def __init__(
        self,
        bet_id: int,
        wager_number: int,
        bet_status: ParlayBetBetStatus,
        bet_type: str,
        win: float,
        risk: float,
        odds_format: OddsFormat,
        update_sequence: int,
        legs: List[ParlayLeg],
        unique_request_id: str = None,
        win_loss: float = None,
        customer_commission: float = None,
        cancellation_reason: CancellationReason = None,
        price: float = None,
        final_price: float = None,
    ):
        self.bet_id = bet_id
        if unique_request_id is not None:
            self.unique_request_id = unique_request_id
        self.wager_number = wager_number
        self.bet_status = self._enum_matching(
            bet_status, ParlayBetBetStatus.list(), "bet_status"
        )
        self.bet_type = bet_type
        self.win = win
        self.risk = risk
        if win_loss is not None:
            self.win_loss = win_loss
        self.odds_format = self._enum_matching(
            odds_format, OddsFormat.list(), "odds_format"
        )
        if customer_commission is not None:
            self.customer_commission = customer_commission
        if cancellation_reason is not None:
            self.cancellation_reason = self._define_object(
                cancellation_reason, CancellationReason
            )
        self.update_sequence = update_sequence
        self.legs = self._define_list(legs, ParlayLeg)
        if price is not None:
            self.price = price
        if final_price is not None:
            self.final_price = final_price



# This file was generated by liblab | https://liblab.com/

import re
from typing import List, Union, get_origin, get_args
from enum import Enum


class BaseModel:
    """
    A base class that most of the models in the SDK inherited from.
    """

    def __init__(self):
        pass

    def _pattern_matching(self, value: str, pattern: str, variable_name: str):
        """
        Checks if a value matches a regex pattern and returns the value if there's a match.

        :param value: The value to be checked.
        :type value: str
        :param pattern: The regex pattern.
        :type pattern: str
        :param variable_name: The variable name.
        :type variable_name: str
        :return: The value if it matches the pattern.
        :rtype: str
        :raises ValueError: If the value does not match the pattern.
        """
        if value is None:
            return None

        if re.match(r"{}".format(pattern), value):
            return value
        else:
            raise ValueError(
                f"Invalid value for {variable_name}: must match {pattern}, received {value}"
            )

    def _enum_matching(
        self, value: Union[str, Enum], enum_values: List[str], variable_name: str
    ):
        """
        Checks if a value (str or enum) matches the required enum values and returns the value if there's a match.

        :param value: The value to be checked.
        :type value: Union[str, Enum]
        :param enum_values: The list of valid enum values.
        :type enum_values: List[str]
        :param variable_name: The variable name.
        :type variable_name: str
        :return: The value if it matches one of the enum values.
        :rtype: Union[str, Enum]
        :raises ValueError: If the value does not match any of the enum values.
        """
        if value is None:
            return None

        str_value = value.value if isinstance(value, Enum) else value
        if str_value in enum_values:
            return value
        else:
            raise ValueError(
                f"Invalid value for {variable_name}: must match one of {enum_values}, received {value}"
            )

    def _define_object(self, input_data, input_class):
        """
        Check if the input data is an instance of the input class and return the input data if it is.
        Otherwise, return an instance of the input class.

        :param input_data: The input data to be checked.
        :param input_class: The class that the input data should be an instance of.
        :return: The input data if it is an instance of input_class, otherwise an instance of input_class.
        :rtype: object
        """
        if input_data is None:
            return None
        elif isinstance(input_data, input_class):
            return input_data
        else:
            return input_class._unmap(input_data)

    def _define_list(self, input_data, list_class):
        """
        Create a list of instances of a specified class from input data.

        :param input_data: The input data to be transformed into a list of instances.
        :param list_class: The class that each instance in the list should be an instance of.
        :return: A list of instances of list_class.
        :rtype: list
        """

        if input_data is None:
            return None

        result = []
        for item in input_data:
            if hasattr(list_class, "__args__") and len(list_class.__args__) > 0:
                class_list = self.__create_class_map(list_class)
                OneOfBaseModel.class_list = class_list
                result.append(OneOfBaseModel.return_one_of(item))
            elif issubclass(list_class, Enum):
                result.append(
                    self._enum_matching(item, list_class.list(), list_class.__name__)
                )
            elif isinstance(item, list_class):
                result.append(item)
            elif isinstance(item, dict):
                result.append(list_class._unmap(item))
            else:
                result.append(list_class(item))
        return result

    def __create_class_map(self, union_type):
        """
        Create a dictionary that maps class names to the actual classes in a Union type.

        :param union_type: The Union type to create a class map for.
        :return: A dictionary mapping class names to classes.
        :rtype: dict
        """
        class_map = {}
        for arg in union_type.__args__:
            if arg.__name__:
                class_map[arg.__name__] = arg
        return class_map

    def _get_representation(self, level=0):
        """
        Get a string representation of the model.

        :param int level: The indentation level.
        :return: A string representation of the model.
        """
        indent = "    " * level
        representation_lines = []

        for attr, value in vars(self).items():
            if value is not None:
                value_representation = (
                    value._get_representation(level + 1)
                    if hasattr(value, "_get_representation")
                    else repr(value)
                )
                representation_lines.append(
                    f"{indent}    {attr}={value_representation}"
                )

        return (
            f"{self.__class__.__name__}(\n"
            + ",\n".join(representation_lines)
            + f"\n{indent})"
        )

    def __str__(self):
        return self._get_representation()

    def __repr__(self):
        return self._get_representation()


class OneOfBaseModel:
    """
    A base class for handling 'oneOf' models where multiple class constructors are available,
    and the appropriate one is determined based on the input data.

    :ivar dict class_list: A dictionary mapping class names to their constructors.
    """

    class_list = {}

    @classmethod
    def return_one_of(cls, input_data):
        """
        Attempts to initialize an instance of one of the classes in the class_list
        based on the provided input data.

        :param input_data: Input data used for initialization.
        :return: An instance of one of the classes specified.
        :rtype: object
        :raises ValueError: If no class can be initialized with the provided input data,
            or if optional parameters don't match the input data.
        """
        if input_data is None:
            return None

        if isinstance(input_data, (str, float, int, bool)):
            return input_data

        for class_constructor in cls.class_list.values():
            exception_list = []
            try:
                # Check if the class is a only a TypeHint
                origin = get_origin(class_constructor)
                if origin is not None and isinstance(input_data, list):
                    list_instance = cls._get_list_instance(
                        input_data, class_constructor, origin
                    )
                    if list_instance is not None:
                        return list_instance
                    else:
                        continue  # Try the next class constructor

                # Check if the input_data is already an instance of the class
                if isinstance(input_data, class_constructor):
                    return input_data

                # Check if the input_data is a dictionary that can be used to initialize the class
                elif isinstance(input_data, dict):
                    instance = class_constructor._unmap(input_data)
                    if cls._check_params(input_data, instance):
                        return instance
            except Exception as e:
                exception_list.append({"class": class_constructor, "exception": e})

        cls._raise_one_of_error(exception_list)

    @classmethod
    def _get_list_instance(cls, input_data, class_constructor, origin):
        """
        Return the list of elements for a given class constructor and origin type.

        :param input_data: The input data to check.
        :param class_constructor: The constructor of the class to check against.
        :param origin: The origin type to check against.
        :return: The input data if all elements are instances of the type specified in the class_constructor,
            or a new list with each item unmapped.
        """
        args = get_args(class_constructor)
        if isinstance(input_data, origin):
            if args and len(args) == 1 and isinstance(input_data, list):
                inner_type = args[0]
                if all(isinstance(item, inner_type) for item in input_data):
                    return input_data
                else:
                    return [inner_type._unmap(item) for item in input_data]

    @classmethod
    def _check_params(cls, raw_input, instance):
        """
        Checks if the optional parameters in the instance match the keys in the input data,
        ensuring compliance with one of the models.

        :param dict raw_input: Input data used for initialization.
        :param object instance: An instance of one of the classes specified in the 'oneOf' model.
        :return: True if the optional parameters in the instance match the keys in the input data, False otherwise.
        """
        input_values = {k: v for k, v in raw_input.items() if v is not None}.values()
        instance_map = instance._map()
        instance_values = {
            k: v for k, v in instance_map.items() if v is not None
        }.values()
        return len(input_values) == len(instance_values)

    @classmethod
    def _raise_one_of_error(cls, exception_list):
        """
        Raises a ValueError with the appropriate error message for one of models.

        :param exception_list: List of exceptions that occurred.
        :type exception_list: list
        :raises ValueError: If input data does not match any of the models.
        """
        if not exception_list:
            return
        exception_messages = "\n".join(
            f"Class: {exception['class']}, Exception: {exception['exception']}"
            for exception in exception_list
        )
        raise ValueError(
            f"Input data must match one of the models: {list(cls.class_list.keys())}"
            f"Errors occurred:\n{exception_messages}"
        )



# This file was generated by liblab | https://liblab.com/

from .utils.validator import Validator
from .utils.base_service import BaseService
from ..net.transport.serializer import Serializer
from ..models.utils.cast_models import cast_models
from ..models.betting_status_response import BettingStatusResponse


class BettingStatusService(BaseService):

    @cast_models
    def bets_get_betting_status(self) -> BettingStatusResponse:
        """Returns current betting status. During maintenance windows betting could be disabled, you can call this operation to check the current betting status.

        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: OK
        :rtype: BettingStatusResponse
        """

        serialized_request = (
            Serializer(
                f"{self.base_url}/v4/bets/betting-status", self.get_default_headers()
            )
            .serialize()
            .set_method("GET")
        )

        response = self.send_request(serialized_request)

        return BettingStatusResponse._unmap(response)



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .odds_format import OddsFormat
from .teaser_bet_leg import TeaserBetLeg


@JsonMap(
    {
        "unique_request_id": "uniqueRequestId",
        "teaser_id": "teaserId",
        "odds_format": "oddsFormat",
        "win_risk_stake": "winRiskStake",
    }
)
class PlaceTeaserBetRequest(BaseModel):
    """PlaceTeaserBetRequest

    :param unique_request_id: Client generated GUID for uniquely identifying the bet., defaults to None
    :type unique_request_id: str, optional
    :param teaser_id: Unique identifier. Teaser details can be retrieved from a call to Get Teaser Groups endpoint., defaults to None
    :type teaser_id: int, optional
    :param odds_format: Bet odds format.  <br>AMERICAN = American odds format,  <br>DECIMAL = Decimal (European) odds format,  <br>HONGKONG = Hong Kong odds format,  <br>INDONESIAN = Indonesian odds format,  <br>MALAY = Malaysian odds format <br>, defaults to None
    :type odds_format: OddsFormat, optional
    :param win_risk_stake: Whether the stake amount is risk or win amount., defaults to None
    :type win_risk_stake: str, optional
    :param stake: amount in client’s currency., defaults to None
    :type stake: float, optional
    :param legs: Collection of legs., defaults to None
    :type legs: List[TeaserBetLeg], optional
    """

    def __init__(
        self,
        unique_request_id: str = None,
        teaser_id: int = None,
        odds_format: OddsFormat = None,
        win_risk_stake: str = None,
        stake: float = None,
        legs: List[TeaserBetLeg] = None,
    ):
        if unique_request_id is not None:
            self.unique_request_id = unique_request_id
        if teaser_id is not None:
            self.teaser_id = teaser_id
        if odds_format is not None:
            self.odds_format = self._enum_matching(
                odds_format, OddsFormat.list(), "odds_format"
            )
        if win_risk_stake is not None:
            self.win_risk_stake = win_risk_stake
        if stake is not None:
            self.stake = stake
        if legs is not None:
            self.legs = self._define_list(legs, TeaserBetLeg)



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from enum import Enum
from .utils.json_map import JsonMap
from .base import BaseModel
from .odds_format import OddsFormat


class PlaceBetRequestWinRiskStake(Enum):
    """An enumeration representing different categories.

    :cvar WIN: "WIN"
    :vartype WIN: str
    :cvar RISK: "RISK"
    :vartype RISK: str
    """

    WIN = "WIN"
    RISK = "RISK"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, PlaceBetRequestWinRiskStake._member_map_.values())
        )


class FillType(Enum):
    """An enumeration representing different categories.

    :cvar NORMAL: "NORMAL"
    :vartype NORMAL: str
    :cvar FILLANDKILL: "FILLANDKILL"
    :vartype FILLANDKILL: str
    :cvar FILLMAXLIMIT: "FILLMAXLIMIT"
    :vartype FILLMAXLIMIT: str
    """

    NORMAL = "NORMAL"
    FILLANDKILL = "FILLANDKILL"
    FILLMAXLIMIT = "FILLMAXLIMIT"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, FillType._member_map_.values()))


class PlaceBetRequestBetType(Enum):
    """An enumeration representing different categories.

    :cvar MONEYLINE: "MONEYLINE"
    :vartype MONEYLINE: str
    :cvar TEAM_TOTAL_POINTS: "TEAM_TOTAL_POINTS"
    :vartype TEAM_TOTAL_POINTS: str
    :cvar SPREAD: "SPREAD"
    :vartype SPREAD: str
    :cvar TOTAL_POINTS: "TOTAL_POINTS"
    :vartype TOTAL_POINTS: str
    """

    MONEYLINE = "MONEYLINE"
    TEAM_TOTAL_POINTS = "TEAM_TOTAL_POINTS"
    SPREAD = "SPREAD"
    TOTAL_POINTS = "TOTAL_POINTS"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, PlaceBetRequestBetType._member_map_.values())
        )


class Team(Enum):
    """An enumeration representing different categories.

    :cvar TEAM1: "TEAM1"
    :vartype TEAM1: str
    :cvar TEAM2: "TEAM2"
    :vartype TEAM2: str
    :cvar DRAW: "DRAW"
    :vartype DRAW: str
    """

    TEAM1 = "TEAM1"
    TEAM2 = "TEAM2"
    DRAW = "DRAW"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, Team._member_map_.values()))


class PlaceBetRequestSide(Enum):
    """An enumeration representing different categories.

    :cvar OVER: "OVER"
    :vartype OVER: str
    :cvar UNDER: "UNDER"
    :vartype UNDER: str
    """

    OVER = "OVER"
    UNDER = "UNDER"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, PlaceBetRequestSide._member_map_.values()))


@JsonMap(
    {
        "odds_format": "oddsFormat",
        "unique_request_id": "uniqueRequestId",
        "accept_better_line": "acceptBetterLine",
        "win_risk_stake": "winRiskStake",
        "line_id": "lineId",
        "alt_line_id": "altLineId",
        "fill_type": "fillType",
        "sport_id": "sportId",
        "event_id": "eventId",
        "period_number": "periodNumber",
        "bet_type": "betType",
    }
)
class PlaceBetRequest(BaseModel):
    """Request to place a bet.

    :param odds_format: Bet odds format.  <br>AMERICAN = American odds format,  <br>DECIMAL = Decimal (European) odds format,  <br>HONGKONG = Hong Kong odds format,  <br>INDONESIAN = Indonesian odds format,  <br>MALAY = Malaysian odds format <br>, defaults to None
    :type odds_format: OddsFormat, optional
    :param unique_request_id: This is a Unique ID for PlaceBet requests. This is to support idempotent requests., defaults to None
    :type unique_request_id: str, optional
    :param accept_better_line: Whether or not to accept a bet when there is a line change in favor of the client., defaults to None
    :type accept_better_line: bool, optional
    :param stake: amount in client’s currency., defaults to None
    :type stake: float, optional
    :param win_risk_stake: Whether the stake amount is risk or win amount., defaults to None
    :type win_risk_stake: PlaceBetRequestWinRiskStake, optional
    :param line_id: Line identification., defaults to None
    :type line_id: int, optional
    :param alt_line_id: Alternate line identification., defaults to None
    :type alt_line_id: int, optional
    :param fill_type: NORMAL - bet will be placed on specified stake.  <br>FILLANDKILL - If the stake is over the max limit, bet will be placed on max limit, otherwise it will be placed on specified stake.  <br>FILLMAXLIMIT - bet will be places on max limit, stake amount will be ignored. Please note that maximum limits can change at any moment, which may result in risking more than anticipated. This option is replacement of isMaxStakeBet from v1/bets/place'<br>, defaults to None
    :type fill_type: FillType, optional
    :param sport_id: sport_id, defaults to None
    :type sport_id: int, optional
    :param event_id: event_id, defaults to None
    :type event_id: int, optional
    :param period_number: period_number, defaults to None
    :type period_number: int, optional
    :param bet_type: Bet type., defaults to None
    :type bet_type: PlaceBetRequestBetType, optional
    :param team: Team type., defaults to None
    :type team: Team, optional
    :param side: Side type., defaults to None
    :type side: PlaceBetRequestSide, optional
    """

    def __init__(
        self,
        odds_format: OddsFormat = None,
        unique_request_id: str = None,
        accept_better_line: bool = None,
        stake: float = None,
        win_risk_stake: PlaceBetRequestWinRiskStake = None,
        line_id: int = None,
        alt_line_id: int = None,
        fill_type: FillType = None,
        sport_id: int = None,
        event_id: int = None,
        period_number: int = None,
        bet_type: PlaceBetRequestBetType = None,
        team: Team = None,
        side: PlaceBetRequestSide = None,
    ):
        if odds_format is not None:
            self.odds_format = self._enum_matching(
                odds_format, OddsFormat.list(), "odds_format"
            )
        if unique_request_id is not None:
            self.unique_request_id = unique_request_id
        if accept_better_line is not None:
            self.accept_better_line = accept_better_line
        if stake is not None:
            self.stake = stake
        if win_risk_stake is not None:
            self.win_risk_stake = self._enum_matching(
                win_risk_stake, PlaceBetRequestWinRiskStake.list(), "win_risk_stake"
            )
        if line_id is not None:
            self.line_id = line_id
        if alt_line_id is not None:
            self.alt_line_id = alt_line_id
        if fill_type is not None:
            self.fill_type = self._enum_matching(
                fill_type, FillType.list(), "fill_type"
            )
        if sport_id is not None:
            self.sport_id = sport_id
        if event_id is not None:
            self.event_id = event_id
        if period_number is not None:
            self.period_number = period_number
        if bet_type is not None:
            self.bet_type = self._enum_matching(
                bet_type, PlaceBetRequestBetType.list(), "bet_type"
            )
        if team is not None:
            self.team = self._enum_matching(team, Team.list(), "team")
        if side is not None:
            self.side = self._enum_matching(side, PlaceBetRequestSide.list(), "side")



# This file was generated by liblab | https://liblab.com/

"""
An enum class containing all the possible environments for the SDK
"""
from enum import Enum


class Environment(Enum):
    """The environments available for the SDK"""

    DEFAULT = "https://api.pinnacle.com/v1"



# This file was generated by liblab | https://liblab.com/

from enum import Enum


class BetsGetBetsByTypeV4BetType(Enum):
    """An enumeration representing different categories.

    :cvar SPREAD: "SPREAD"
    :vartype SPREAD: str
    :cvar MONEYLINE: "MONEYLINE"
    :vartype MONEYLINE: str
    :cvar TOTAL_POINTS: "TOTAL_POINTS"
    :vartype TOTAL_POINTS: str
    :cvar TEAM_TOTAL_POINTS: "TEAM_TOTAL_POINTS"
    :vartype TEAM_TOTAL_POINTS: str
    :cvar SPECIAL: "SPECIAL"
    :vartype SPECIAL: str
    :cvar PARLAY: "PARLAY"
    :vartype PARLAY: str
    :cvar TEASER: "TEASER"
    :vartype TEASER: str
    :cvar MANUAL: "MANUAL"
    :vartype MANUAL: str
    """

    SPREAD = "SPREAD"
    MONEYLINE = "MONEYLINE"
    TOTAL_POINTS = "TOTAL_POINTS"
    TEAM_TOTAL_POINTS = "TEAM_TOTAL_POINTS"
    SPECIAL = "SPECIAL"
    PARLAY = "PARLAY"
    TEASER = "TEASER"
    MANUAL = "MANUAL"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, BetsGetBetsByTypeV4BetType._member_map_.values())
        )



# This file was generated by liblab | https://liblab.com/

from enum import Enum


class SortDir(Enum):
    """An enumeration representing different categories.

    :cvar ASC: "ASC"
    :vartype ASC: str
    :cvar DESC: "DESC"
    :vartype DESC: str
    """

    ASC = "ASC"
    DESC = "DESC"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, SortDir._member_map_.values()))



# This file was generated by liblab | https://liblab.com/

from enum import Enum
from .utils.json_map import JsonMap
from .base import BaseModel


class ParlayLegRequestLegBetType(Enum):
    """An enumeration representing different categories.

    :cvar MONEYLINE: "MONEYLINE"
    :vartype MONEYLINE: str
    :cvar SPREAD: "SPREAD"
    :vartype SPREAD: str
    :cvar TOTAL_POINTS: "TOTAL_POINTS"
    :vartype TOTAL_POINTS: str
    """

    MONEYLINE = "MONEYLINE"
    SPREAD = "SPREAD"
    TOTAL_POINTS = "TOTAL_POINTS"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, ParlayLegRequestLegBetType._member_map_.values())
        )


class ParlayLegRequestSide(Enum):
    """An enumeration representing different categories.

    :cvar OVER: "OVER"
    :vartype OVER: str
    :cvar UNDER: "UNDER"
    :vartype UNDER: str
    """

    OVER = "OVER"
    UNDER = "UNDER"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, ParlayLegRequestSide._member_map_.values()))


@JsonMap(
    {
        "unique_leg_id": "uniqueLegId",
        "line_id": "lineId",
        "alt_line_id": "altLineId",
        "sport_id": "sportId",
        "event_id": "eventId",
        "period_number": "periodNumber",
        "leg_bet_type": "legBetType",
    }
)
class ParlayLegRequest(BaseModel):
    """ParlayLegRequest

    :param unique_leg_id: Unique id of the leg. It's used to identify and match legs in the response., defaults to None
    :type unique_leg_id: str, optional
    :param line_id: Line identification., defaults to None
    :type line_id: int, optional
    :param alt_line_id: Alternate line identification., defaults to None
    :type alt_line_id: int, optional
    :param sport_id: Sport identification., defaults to None
    :type sport_id: int, optional
    :param event_id: Event identification., defaults to None
    :type event_id: int, optional
    :param period_number: This represents the period of the match. For example, for soccer we have: 0 -  Game, 1 - 1st Half and 2 - 2nd Half, defaults to None
    :type period_number: int, optional
    :param leg_bet_type: Only SPREAD, MONEYLINE and TOTAL_POINTS are supported., defaults to None
    :type leg_bet_type: ParlayLegRequestLegBetType, optional
    :param team: Chosen team type. This is needed only for SPREAD and MONEYLINE bet types., defaults to None
    :type team: str, optional
    :param side: Chosen side type. This is needed only for TOTAL_POINTS bet type., defaults to None
    :type side: ParlayLegRequestSide, optional
    """

    def __init__(
        self,
        unique_leg_id: str = None,
        line_id: int = None,
        alt_line_id: int = None,
        sport_id: int = None,
        event_id: int = None,
        period_number: int = None,
        leg_bet_type: ParlayLegRequestLegBetType = None,
        team: str = None,
        side: ParlayLegRequestSide = None,
    ):
        if unique_leg_id is not None:
            self.unique_leg_id = unique_leg_id
        if line_id is not None:
            self.line_id = line_id
        if alt_line_id is not None:
            self.alt_line_id = alt_line_id
        if sport_id is not None:
            self.sport_id = sport_id
        if event_id is not None:
            self.event_id = event_id
        if period_number is not None:
            self.period_number = period_number
        if leg_bet_type is not None:
            self.leg_bet_type = self._enum_matching(
                leg_bet_type, ParlayLegRequestLegBetType.list(), "leg_bet_type"
            )
        if team is not None:
            self.team = team
        if side is not None:
            self.side = self._enum_matching(side, ParlayLegRequestSide.list(), "side")



# This file was generated by liblab | https://liblab.com/

from .response import Response
from typing import Optional


class RequestError(IOError):
    """
    Class representing a Request Error.

    :ivar bool is_http_error: Indicates if the error is an HTTP error.
    :ivar int status: The status code of the HTTP error.
    :ivar Optional[Response] response: The response associated with the error.
    """

    def __init__(
        self,
        message: str,
        status: Optional[int] = None,
        response: Optional[Response] = None,
        stack: Optional["RequestError"] = None,
    ):
        """
        Initialize a new instance of RequestError.

        :param str message: The error message.
        :param Optional[int] status: The status code of the HTTP error.
        :param Optional[Response] response: The response associated with the error.
        """
        super().__init__(message)
        self.response = response
        self.stack = stack

        if status is not None:
            self.status = status
            self.is_http_error = True
        else:
            self.status = -1
            self.is_http_error = False

    def __str__(self):
        """
        Get the string representation of the error.

        :return: The string representation of the error.
        :rtype: str
        """
        error_stack = []
        current_error = self
        while current_error is not None:
            error_stack.append(
                f"Error: {super().__str__()}, Status Code: {current_error.status}"
            )
            current_error = current_error.stack
        return "\n".join(error_stack)



# This file was generated by liblab | https://liblab.com/

from enum import Enum
from .utils.json_map import JsonMap
from .base import BaseModel


class SpecialBetResponseStatus(Enum):
    """An enumeration representing different categories.

    :cvar ACCEPTED: "ACCEPTED"
    :vartype ACCEPTED: str
    :cvar PROCESSED_WITH_ERROR: "PROCESSED_WITH_ERROR"
    :vartype PROCESSED_WITH_ERROR: str
    """

    ACCEPTED = "ACCEPTED"
    PROCESSED_WITH_ERROR = "PROCESSED_WITH_ERROR"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, SpecialBetResponseStatus._member_map_.values())
        )


class SpecialBetResponseErrorCode(Enum):
    """An enumeration representing different categories.

    :cvar ALL_BETTING_CLOSED: "ALL_BETTING_CLOSED"
    :vartype ALL_BETTING_CLOSED: str
    :cvar ABOVE_MAX_BET_AMOUNT: "ABOVE_MAX_BET_AMOUNT"
    :vartype ABOVE_MAX_BET_AMOUNT: str
    :cvar BELOW_MIN_BET_AMOUNT: "BELOW_MIN_BET_AMOUNT"
    :vartype BELOW_MIN_BET_AMOUNT: str
    :cvar BLOCKED_BETTING: "BLOCKED_BETTING"
    :vartype BLOCKED_BETTING: str
    :cvar BLOCKED_CLIENT: "BLOCKED_CLIENT"
    :vartype BLOCKED_CLIENT: str
    :cvar CONTEST_NOT_FOUND: "CONTEST_NOT_FOUND"
    :vartype CONTEST_NOT_FOUND: str
    :cvar DUPLICATED_REQUEST: "DUPLICATED_REQUEST"
    :vartype DUPLICATED_REQUEST: str
    :cvar INCOMPLETE_CUSTOMER_BETTING_PROFILE: "INCOMPLETE_CUSTOMER_BETTING_PROFILE"
    :vartype INCOMPLETE_CUSTOMER_BETTING_PROFILE: str
    :cvar INSUFFICIENT_FUNDS: "INSUFFICIENT_FUNDS"
    :vartype INSUFFICIENT_FUNDS: str
    :cvar INVALID_COUNTRY: "INVALID_COUNTRY"
    :vartype INVALID_COUNTRY: str
    :cvar INVALID_REQUEST: "INVALID_REQUEST"
    :vartype INVALID_REQUEST: str
    :cvar LINE_CHANGED: "LINE_CHANGED"
    :vartype LINE_CHANGED: str
    :cvar PAST_CUTOFFTIME: "PAST_CUTOFFTIME"
    :vartype PAST_CUTOFFTIME: str
    :cvar RESPONSIBLE_BETTING_LOSS_LIMIT_EXCEEDED: "RESPONSIBLE_BETTING_LOSS_LIMIT_EXCEEDED"
    :vartype RESPONSIBLE_BETTING_LOSS_LIMIT_EXCEEDED: str
    :cvar RESPONSIBLE_BETTING_RISK_LIMIT_EXCEEDED: "RESPONSIBLE_BETTING_RISK_LIMIT_EXCEEDED"
    :vartype RESPONSIBLE_BETTING_RISK_LIMIT_EXCEEDED: str
    :cvar SYSTEM_ERROR_1: "SYSTEM_ERROR_1"
    :vartype SYSTEM_ERROR_1: str
    :cvar SYSTEM_ERROR_2: "SYSTEM_ERROR_2"
    :vartype SYSTEM_ERROR_2: str
    :cvar UNIQUE_REQUEST_ID_REQUIRED: "UNIQUE_REQUEST_ID_REQUIRED"
    :vartype UNIQUE_REQUEST_ID_REQUIRED: str
    :cvar INVALID_CUSTOMER_PROFILE: "INVALID_CUSTOMER_PROFILE"
    :vartype INVALID_CUSTOMER_PROFILE: str
    :cvar BETTING_SUSPENDED: "BETTING_SUSPENDED"
    :vartype BETTING_SUSPENDED: str
    """

    ALL_BETTING_CLOSED = "ALL_BETTING_CLOSED"
    ABOVE_MAX_BET_AMOUNT = "ABOVE_MAX_BET_AMOUNT"
    BELOW_MIN_BET_AMOUNT = "BELOW_MIN_BET_AMOUNT"
    BLOCKED_BETTING = "BLOCKED_BETTING"
    BLOCKED_CLIENT = "BLOCKED_CLIENT"
    CONTEST_NOT_FOUND = "CONTEST_NOT_FOUND"
    DUPLICATED_REQUEST = "DUPLICATED_REQUEST"
    INCOMPLETE_CUSTOMER_BETTING_PROFILE = "INCOMPLETE_CUSTOMER_BETTING_PROFILE"
    INSUFFICIENT_FUNDS = "INSUFFICIENT_FUNDS"
    INVALID_COUNTRY = "INVALID_COUNTRY"
    INVALID_REQUEST = "INVALID_REQUEST"
    LINE_CHANGED = "LINE_CHANGED"
    PAST_CUTOFFTIME = "PAST_CUTOFFTIME"
    RESPONSIBLE_BETTING_LOSS_LIMIT_EXCEEDED = "RESPONSIBLE_BETTING_LOSS_LIMIT_EXCEEDED"
    RESPONSIBLE_BETTING_RISK_LIMIT_EXCEEDED = "RESPONSIBLE_BETTING_RISK_LIMIT_EXCEEDED"
    SYSTEM_ERROR_1 = "SYSTEM_ERROR_1"
    SYSTEM_ERROR_2 = "SYSTEM_ERROR_2"
    UNIQUE_REQUEST_ID_REQUIRED = "UNIQUE_REQUEST_ID_REQUIRED"
    INVALID_CUSTOMER_PROFILE = "INVALID_CUSTOMER_PROFILE"
    BETTING_SUSPENDED = "BETTING_SUSPENDED"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, SpecialBetResponseErrorCode._member_map_.values())
        )


@JsonMap(
    {
        "error_code": "errorCode",
        "bet_id": "betId",
        "unique_request_id": "uniqueRequestId",
        "better_line_was_accepted": "betterLineWasAccepted",
    }
)
class SpecialBetResponse(BaseModel):
    """SpecialBetResponse

    :param status: Status of the request., defaults to None
    :type status: SpecialBetResponseStatus, optional
    :param error_code: When Status is PROCESSED_WITH_ERROR, provides a code indicating the specific problem.<br><br>ALL_BETTING_CLOSED = Betting is not allowed at this moment. This may happen during system maintenance.  <br> ABOVE_MAX_BET_AMOUNT = Stake is above allowed maximum amount,  <br> BELOW_MIN_BET_AMOUNT = Stake is below allowed minimum amount,  <br> BLOCKED_BETTING = Betting is suspended for the client,  <br> BLOCKED_CLIENT = Client is no longer active,  <br> CONTEST_NOT_FOUND = Incorrect contest id provided or contest is no longer available,  <br> DUPLICATED_REQUEST = UniqueRequestId must be unique for each bet,  <br> INCOMPLETE_CUSTOMER_BETTING_PROFILE = Customer profile could not be loaded,   <br> INSUFFICIENT_FUNDS = Bet is submitted by a client with insufficient funds,  <br> INVALID_COUNTRY = Client country is not allowed for betting,  <br> INVALID_REQUEST = Special bet request is not valid,  <br> LINE_CHANGED = Bet is submitted on a line that has changed,  <br> PAST_CUTOFFTIME = Bet is submitted on a game after the betting cutoff time,  <br> RESPONSIBLE_BETTING_LOSS_LIMIT_EXCEEDED = Self-imposed loss limit exceeded,  <br> RESPONSIBLE_BETTING_RISK_LIMIT_EXCEEDED = Self-imposed risk limit exceeded, <br> SYSTEM_ERROR_1 = Unexpected error,  <br> SYSTEM_ERROR_2 = Unexpected error,  <br> UNIQUE_REQUEST_ID_REQUIRED = UniqueRequestId is missing,  <br> INVALID_CUSTOMER_PROFILE = System configuration issue, <br>BETTING_SUSPENDED - Due to anomalous market circumstances bets are not currently being accepted on this line. Try again with next LineId.<br>, defaults to None
    :type error_code: SpecialBetResponseErrorCode, optional
    :param bet_id: Bet identifier. Populated in case of accepted bet., defaults to None
    :type bet_id: int, optional
    :param unique_request_id: Unique identifier provided in the request., defaults to None
    :type unique_request_id: str, optional
    :param win: Win amount. Populated in case of accepted bet., defaults to None
    :type win: float, optional
    :param risk: Risk amount.  Populated in case of accepted bet., defaults to None
    :type risk: float, optional
    :param price: Bet price. Populated in case of accepted bet., defaults to None
    :type price: float, optional
    :param better_line_was_accepted: Whether or not the bet was accepted on the line that changed in favour of client. This can be true only if acceptBetterLine in the Place Bet request is set to TRUE., defaults to None
    :type better_line_was_accepted: bool, optional
    """

    def __init__(
        self,
        status: SpecialBetResponseStatus = None,
        error_code: SpecialBetResponseErrorCode = None,
        bet_id: int = None,
        unique_request_id: str = None,
        win: float = None,
        risk: float = None,
        price: float = None,
        better_line_was_accepted: bool = None,
    ):
        if status is not None:
            self.status = self._enum_matching(
                status, SpecialBetResponseStatus.list(), "status"
            )
        if error_code is not None:
            self.error_code = self._enum_matching(
                error_code, SpecialBetResponseErrorCode.list(), "error_code"
            )
        if bet_id is not None:
            self.bet_id = bet_id
        if unique_request_id is not None:
            self.unique_request_id = unique_request_id
        if win is not None:
            self.win = win
        if risk is not None:
            self.risk = risk
        if price is not None:
            self.price = price
        if better_line_was_accepted is not None:
            self.better_line_was_accepted = better_line_was_accepted



# This file was generated by liblab | https://liblab.com/

from enum import Enum
from .utils.json_map import JsonMap
from .base import BaseModel


class BettingStatusResponseStatus(Enum):
    """An enumeration representing different categories.

    :cvar ALL_BETTING_ENABLED: "ALL_BETTING_ENABLED"
    :vartype ALL_BETTING_ENABLED: str
    :cvar ALL_LIVE_BETTING_CLOSED: "ALL_LIVE_BETTING_CLOSED"
    :vartype ALL_LIVE_BETTING_CLOSED: str
    :cvar ALL_BETTING_CLOSED: "ALL_BETTING_CLOSED"
    :vartype ALL_BETTING_CLOSED: str
    """

    ALL_BETTING_ENABLED = "ALL_BETTING_ENABLED"
    ALL_LIVE_BETTING_CLOSED = "ALL_LIVE_BETTING_CLOSED"
    ALL_BETTING_CLOSED = "ALL_BETTING_CLOSED"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, BettingStatusResponseStatus._member_map_.values())
        )


@JsonMap({})
class BettingStatusResponse(BaseModel):
    """BettingStatusResponse

    :param status: Betting status.<br>
    :type status: BettingStatusResponseStatus
    """

    def __init__(self, status: BettingStatusResponseStatus):
        self.status = self._enum_matching(
            status, BettingStatusResponseStatus.list(), "status"
        )



# This file was generated by liblab | https://liblab.com/

from typing import List
from .utils.validator import Validator
from .utils.base_service import BaseService
from ..net.transport.serializer import Serializer
from ..models.utils.cast_models import cast_models
from ..models.sort_dir import SortDir
from ..models.get_bets_by_type_response_v4 import GetBetsByTypeResponseV4
from ..models.bets_get_bets_by_type_v4_bet_type import BetsGetBetsByTypeV4BetType
from ..models.betlist import Betlist
from ..models.bet_statuses import BetStatuses


class GetBetsService(BaseService):

    @cast_models
    def bets_get_bets_by_type_v4(
        self,
        betlist: Betlist = None,
        bet_statuses: List[BetStatuses] = None,
        from_date: str = None,
        to_date: str = None,
        sort_dir: SortDir = None,
        page_size: int = None,
        from_record: int = None,
        betids: List[int] = None,
        unique_request_ids: List[str] = None,
        bet_type: List[BetsGetBetsByTypeV4BetType] = None,
    ) -> GetBetsByTypeResponseV4:
        """Returns bets.


        ### Get running bets by time range:
        ```
        https://api.pinnacle.com/v4/bets?betlist=RUNNING&fromDate=2017-11-21T00:00:00Z&toDate=2017-11-29T00:00:00Z
        ```
        Running bets are queried by *placedAt* date time


        ### Get settled bets by time range:

        ```
        https://api.pinnacle.com/v4/bets?betlist=SETTLED&fromDate=2015-12-28T00:00:00Z&toDate=2015-12-29T00:00:00Z
        ```
        Settled bets are queried by *settledAt* date time
        https://api.pinnacle.com/v4/bets?betlist=SETTLED&fromDate=2017-11-20T00:00:00Z&toDate=2017-11-23T00:00:00Z


        ### Get settled cancelled bets by time range:

        ```
        https://api.pinnacle.com/v4/bets?betList=SETTLED&fromDate=2018-03-01&toDate=2018-03-28&betStatuses=CANCELLED
        ```


        ### Get bets by bet ids:

        ```
        https://api.pinnacle.com/v4/bets?betIds=775856112,775856113,775856114
        ```

        ### Get bets by uniqueRequestIds:

        ```
        https://api.pinnacle.com/v4/bets?uniqueRequestIds=62335222-dae4-479a-8c05-46440ccdd3bb,42335222-dae4-479a-8c05-46440ccdd3bb
        ```

        :param betlist: Type of bet list to return. Not needed when betids is submitted., defaults to None
        :type betlist: Betlist, optional
        :param bet_statuses: Type of bet statues to return. This works only in conjustion with betlist, as additional filter., defaults to None
        :type bet_statuses: List[BetStatuses], optional
        :param from_date: Start date of the requested period. Required when betlist parameter is submitted. Start date can be up to 30 days in the past. Expected format is ISO8601 - can be set to just date or date and time., defaults to None
        :type from_date: str, optional
        :param to_date: End date of the requested period. Required when betlist parameter is submitted. Expected format is ISO8601 - can be set to just date or date and time.  toDate value is exclusive, meaning it cannot be equal to fromDate., defaults to None
        :type to_date: str, optional
        :param sort_dir: Sort direction by postedAt/settledAt. Respected only when querying by date range., defaults to None
        :type sort_dir: SortDir, optional
        :param page_size: Page size in case. Max is 1000. Respected only when querying by date range., defaults to None
        :type page_size: int, optional
        :param from_record: Starting record (inclusive) of the result. Respected only when querying by date range. To fetch next page set it to toRecord+1, defaults to None
        :type from_record: int, optional
        :param betids: A comma separated list of bet ids. When betids is submitted, no other parameter is necessary. Maximum is 100 ids. Works for all non settled bets and all bets settled in the last 30 days., defaults to None
        :type betids: List[int], optional
        :param unique_request_ids: A comma separated list of `uniqueRequestId` from the place bet request. If specified, it's highest priority, all other parameters are ignored. Maximum is 10 ids. If client has bet id, preferred way is to use `betIds` query parameter, you can use `uniqueRequestIds` when you do not  have bet id.
        That are 2 cases when client may not have a bet id:

        1. When you bet on live event with live delay, place bet response in that case does not return bet id, so client can query bet status by `uniqueRequestIds`.
        2. In case of any network issues when client is not sure what happened with his place bet request. Empty response means that the bet was not placed. Please check [Deduplication section](https://www.pinnacle.com/de/api/manual#overview) for more details.

        Note that there is a restriction: querying by uniqueRequestIds  is supported for straight and  special bets and only up to 30 min from the moment the bet was place., defaults to None
        :type unique_request_ids: List[str], optional
        :param bet_type: A comma separated list of bet types., defaults to None
        :type bet_type: List[BetsGetBetsByTypeV4BetType], optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: OK
        :rtype: GetBetsByTypeResponseV4
        """

        Validator(Betlist).is_optional().validate(betlist)
        Validator(BetStatuses).is_array().is_optional().validate(bet_statuses)
        Validator(str).is_optional().validate(from_date)
        Validator(str).is_optional().validate(to_date)
        Validator(SortDir).is_optional().validate(sort_dir)
        Validator(int).is_optional().validate(page_size)
        Validator(int).is_optional().validate(from_record)
        Validator(int).is_array().is_optional().validate(betids)
        Validator(str).is_array().is_optional().validate(unique_request_ids)
        Validator(BetsGetBetsByTypeV4BetType).is_array().is_optional().validate(
            bet_type
        )

        serialized_request = (
            Serializer(f"{self.base_url}/v4/bets", self.get_default_headers())
            .add_query("betlist", betlist)
            .add_query("betStatuses", bet_statuses, explode=False)
            .add_query("fromDate", from_date)
            .add_query("toDate", to_date)
            .add_query("sortDir", sort_dir)
            .add_query("pageSize", page_size)
            .add_query("fromRecord", from_record)
            .add_query("betids", betids, explode=False)
            .add_query("uniqueRequestIds", unique_request_ids, explode=False)
            .add_query("betType", bet_type, explode=False)
            .serialize()
            .set_method("GET")
        )

        response = self.send_request(serialized_request)

        return GetBetsByTypeResponseV4._unmap(response)



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from enum import Enum
from .utils.json_map import JsonMap
from .base import BaseModel
from .odds_format import OddsFormat
from .cancellation_reason import CancellationReason


class StraightBetV4BetStatus(Enum):
    """An enumeration representing different categories.

    :cvar ACCEPTED: "ACCEPTED"
    :vartype ACCEPTED: str
    :cvar CANCELLED: "CANCELLED"
    :vartype CANCELLED: str
    :cvar LOST: "LOST"
    :vartype LOST: str
    :cvar PENDING_ACCEPTANCE: "PENDING_ACCEPTANCE"
    :vartype PENDING_ACCEPTANCE: str
    :cvar REFUNDED: "REFUNDED"
    :vartype REFUNDED: str
    :cvar PUSHED: "PUSHED"
    :vartype PUSHED: str
    :cvar NOT_ACCEPTED: "NOT_ACCEPTED"
    :vartype NOT_ACCEPTED: str
    :cvar WON: "WON"
    :vartype WON: str
    :cvar HALF_WON_HALF_PUSHED: "HALF_WON_HALF_PUSHED"
    :vartype HALF_WON_HALF_PUSHED: str
    :cvar HALF_LOST_HALF_PUSHED: "HALF_LOST_HALF_PUSHED"
    :vartype HALF_LOST_HALF_PUSHED: str
    """

    ACCEPTED = "ACCEPTED"
    CANCELLED = "CANCELLED"
    LOST = "LOST"
    PENDING_ACCEPTANCE = "PENDING_ACCEPTANCE"
    REFUNDED = "REFUNDED"
    PUSHED = "PUSHED"
    NOT_ACCEPTED = "NOT_ACCEPTED"
    WON = "WON"
    HALF_WON_HALF_PUSHED = "HALF_WON_HALF_PUSHED"
    HALF_LOST_HALF_PUSHED = "HALF_LOST_HALF_PUSHED"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, StraightBetV4BetStatus._member_map_.values())
        )


class StraightBetV4BetType(Enum):
    """An enumeration representing different categories.

    :cvar MONEYLINE: "MONEYLINE"
    :vartype MONEYLINE: str
    :cvar TEAM_TOTAL_POINTS: "TEAM_TOTAL_POINTS"
    :vartype TEAM_TOTAL_POINTS: str
    :cvar SPREAD: "SPREAD"
    :vartype SPREAD: str
    :cvar TOTAL_POINTS: "TOTAL_POINTS"
    :vartype TOTAL_POINTS: str
    :cvar SPECIAL: "SPECIAL"
    :vartype SPECIAL: str
    :cvar PARLAY: "PARLAY"
    :vartype PARLAY: str
    :cvar TEASER: "TEASER"
    :vartype TEASER: str
    :cvar MANUAL: "MANUAL"
    :vartype MANUAL: str
    """

    MONEYLINE = "MONEYLINE"
    TEAM_TOTAL_POINTS = "TEAM_TOTAL_POINTS"
    SPREAD = "SPREAD"
    TOTAL_POINTS = "TOTAL_POINTS"
    SPECIAL = "SPECIAL"
    PARLAY = "PARLAY"
    TEASER = "TEASER"
    MANUAL = "MANUAL"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, StraightBetV4BetType._member_map_.values()))


class StraightBetV4Side(Enum):
    """An enumeration representing different categories.

    :cvar OVER: "OVER"
    :vartype OVER: str
    :cvar UNDER: "UNDER"
    :vartype UNDER: str
    """

    OVER = "OVER"
    UNDER = "UNDER"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, StraightBetV4Side._member_map_.values()))


@JsonMap(
    {
        "bet_id": "betId",
        "wager_number": "wagerNumber",
        "placed_at": "placedAt",
        "bet_status": "betStatus",
        "bet_type": "betType",
        "win_loss": "winLoss",
        "odds_format": "oddsFormat",
        "customer_commission": "customerCommission",
        "cancellation_reason": "cancellationReason",
        "update_sequence": "updateSequence",
        "sport_id": "sportId",
        "league_id": "leagueId",
        "event_id": "eventId",
        "team_name": "teamName",
        "period_number": "periodNumber",
        "team1_score": "team1Score",
        "team2_score": "team2Score",
        "ft_team1_score": "ftTeam1Score",
        "ft_team2_score": "ftTeam2Score",
        "p_team1_score": "pTeam1Score",
        "p_team2_score": "pTeam2Score",
        "is_live": "isLive",
        "event_start_time": "eventStartTime",
    }
)
class StraightBetV4(BaseModel):
    """StraightBetV4

    :param bet_id: Bet identification
    :type bet_id: int
    :param wager_number: Wager identification. All bets placed thru the API will have value 1. Website Classic view supports multiple contest(special) bets placement in the same bet slip in that case the bet would have appropriate wager number, as well as all round robin parlay bets.
    :type wager_number: int
    :param placed_at: Date time when the bet was placed.
    :type placed_at: str
    :param bet_status: Bet Status.  <br><br>ACCEPTED = Bet was accepted.<br>PUSHED = Bet was pushed.<br>CANCELLED = Bet is cancelled as per Pinnacle betting rules.  <br>LOST = The bet is settled as lose.  <br>PENDING_ACCEPTANCE = This status is reserved only for live bets. If a live bet is placed during danger zone or live delay is applied, it will be in PENDING_ACCEPTANCE , otherwise in ACCEPTED status. From this status bet can go to ACCEPTED or NOT_ACCEPTED status.  <br>REFUNDED = When an event is cancelled or when the bet is settled as push, the bet will have REFUNDED status.  <br>NOT_ACCEPTED = Bet was not accepted. Bet can be in this status only if it was previously in PENDING_ACCEPTANCE status.  <br>WON = The bet is settled as won.  <br>HALF_WON_HALF_PUSHED = The bet is settled as half won half pushed. Only for asian handicap bets.  <br>HALF_LOST_HALF_PUSHED =  The bet is settled as half lost half pushed. Only for asian handicap bets.<br>
    :type bet_status: StraightBetV4BetStatus
    :param bet_type: Bet type.
    :type bet_type: StraightBetV4BetType
    :param win: Win amount.
    :type win: float
    :param risk: Risk amount.
    :type risk: float
    :param win_loss: Win-Loss for settled bets., defaults to None
    :type win_loss: float, optional
    :param odds_format: Bet odds format.  <br>AMERICAN = American odds format,  <br>DECIMAL = Decimal (European) odds format,  <br>HONGKONG = Hong Kong odds format,  <br>INDONESIAN = Indonesian odds format,  <br>MALAY = Malaysian odds format <br>
    :type odds_format: OddsFormat
    :param customer_commission: Client’s commission on the bet., defaults to None
    :type customer_commission: float, optional
    :param cancellation_reason: Possible keys \:  <br>* correctTeam1Id<br>* correctTeam2Id<br>* correctListedPitcher1<br>* correctListedPitcher2<br>* correctSpread<br>* correctTotalPoints<br>* correctTeam1TotalPoints<br>* correctTeam2TotalPoints<br>* correctTeam1Score<br>* correctTeam2Score<br>* correctTeam1TennisSetsScore<br>* correctTeam2TennisSetsScore<br>, defaults to None
    :type cancellation_reason: CancellationReason, optional
    :param update_sequence: Update Sequence
    :type update_sequence: int
    :param sport_id: sport_id, defaults to None
    :type sport_id: int, optional
    :param league_id: league_id, defaults to None
    :type league_id: int, optional
    :param event_id: event_id, defaults to None
    :type event_id: int, optional
    :param handicap: handicap, defaults to None
    :type handicap: float, optional
    :param price: price, defaults to None
    :type price: float, optional
    :param team_name: team_name, defaults to None
    :type team_name: str, optional
    :param side: Side type., defaults to None
    :type side: StraightBetV4Side, optional
    :param team1: team1, defaults to None
    :type team1: str, optional
    :param team2: team2, defaults to None
    :type team2: str, optional
    :param period_number: period_number, defaults to None
    :type period_number: int, optional
    :param team1_score: Team 1 on the period that the bet was placed on at the moment of placing a bet, only for live bets., defaults to None
    :type team1_score: float, optional
    :param team2_score: Team 2 on the period that the bet was placed on at the moment of placing a bet, only for live bets., defaults to None
    :type team2_score: float, optional
    :param ft_team1_score: Full time team 1 score, only for settled bets., defaults to None
    :type ft_team1_score: float, optional
    :param ft_team2_score: Full time team 2 score, only for settled bets., defaults to None
    :type ft_team2_score: float, optional
    :param p_team1_score: .End of period team 1 score, only for settled bets. If the bet was placed on Game period (periodNumber =0), this will be null . , defaults to None
    :type p_team1_score: float, optional
    :param p_team2_score: End of period team 2 score, only for settled bets. If the bet was placed on Game period (periodNumber =0), this will be null, defaults to None
    :type p_team2_score: float, optional
    :param is_live: Whether the bet is on live event, defaults to None
    :type is_live: bool, optional
    :param event_start_time: Date time when the event starts., defaults to None
    :type event_start_time: str, optional
    """

    def __init__(
        self,
        bet_id: int,
        wager_number: int,
        placed_at: str,
        bet_status: StraightBetV4BetStatus,
        bet_type: StraightBetV4BetType,
        win: float,
        risk: float,
        odds_format: OddsFormat,
        update_sequence: int,
        win_loss: float = None,
        customer_commission: float = None,
        cancellation_reason: CancellationReason = None,
        sport_id: int = None,
        league_id: int = None,
        event_id: int = None,
        handicap: float = None,
        price: float = None,
        team_name: str = None,
        side: StraightBetV4Side = None,
        team1: str = None,
        team2: str = None,
        period_number: int = None,
        team1_score: float = None,
        team2_score: float = None,
        ft_team1_score: float = None,
        ft_team2_score: float = None,
        p_team1_score: float = None,
        p_team2_score: float = None,
        is_live: bool = None,
        event_start_time: str = None,
    ):
        self.bet_id = bet_id
        self.wager_number = wager_number
        self.placed_at = placed_at
        self.bet_status = self._enum_matching(
            bet_status, StraightBetV4BetStatus.list(), "bet_status"
        )
        self.bet_type = self._enum_matching(
            bet_type, StraightBetV4BetType.list(), "bet_type"
        )
        self.win = win
        self.risk = risk
        if win_loss is not None:
            self.win_loss = win_loss
        self.odds_format = self._enum_matching(
            odds_format, OddsFormat.list(), "odds_format"
        )
        if customer_commission is not None:
            self.customer_commission = customer_commission
        if cancellation_reason is not None:
            self.cancellation_reason = self._define_object(
                cancellation_reason, CancellationReason
            )
        self.update_sequence = update_sequence
        if sport_id is not None:
            self.sport_id = sport_id
        if league_id is not None:
            self.league_id = league_id
        if event_id is not None:
            self.event_id = event_id
        if handicap is not None:
            self.handicap = handicap
        if price is not None:
            self.price = price
        if team_name is not None:
            self.team_name = team_name
        if side is not None:
            self.side = self._enum_matching(side, StraightBetV4Side.list(), "side")
        if team1 is not None:
            self.team1 = team1
        if team2 is not None:
            self.team2 = team2
        if period_number is not None:
            self.period_number = period_number
        if team1_score is not None:
            self.team1_score = team1_score
        if team2_score is not None:
            self.team2_score = team2_score
        if ft_team1_score is not None:
            self.ft_team1_score = ft_team1_score
        if ft_team2_score is not None:
            self.ft_team2_score = ft_team2_score
        if p_team1_score is not None:
            self.p_team1_score = p_team1_score
        if p_team2_score is not None:
            self.p_team2_score = p_team2_score
        if is_live is not None:
            self.is_live = is_live
        if event_start_time is not None:
            self.event_start_time = event_start_time



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from enum import Enum
from .utils.json_map import JsonMap
from .base import BaseModel
from .odds_format import OddsFormat
from .cancellation_reason import CancellationReason


class SpecialBetBetStatus(Enum):
    """An enumeration representing different categories.

    :cvar ACCEPTED: "ACCEPTED"
    :vartype ACCEPTED: str
    :cvar CANCELLED: "CANCELLED"
    :vartype CANCELLED: str
    :cvar LOSE: "LOSE"
    :vartype LOSE: str
    :cvar REFUNDED: "REFUNDED"
    :vartype REFUNDED: str
    :cvar WON: "WON"
    :vartype WON: str
    """

    ACCEPTED = "ACCEPTED"
    CANCELLED = "CANCELLED"
    LOSE = "LOSE"
    REFUNDED = "REFUNDED"
    WON = "WON"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, SpecialBetBetStatus._member_map_.values()))


@JsonMap(
    {
        "bet_id": "betId",
        "unique_request_id": "uniqueRequestId",
        "wager_number": "wagerNumber",
        "placed_at": "placedAt",
        "bet_status": "betStatus",
        "bet_type": "betType",
        "win_loss": "winLoss",
        "odds_format": "oddsFormat",
        "customer_commission": "customerCommission",
        "cancellation_reason": "cancellationReason",
        "update_sequence": "updateSequence",
        "special_id": "specialId",
        "special_name": "specialName",
        "contestant_id": "contestantId",
        "contestant_name": "contestantName",
        "sport_id": "sportId",
        "league_id": "leagueId",
        "event_id": "eventId",
        "period_number": "periodNumber",
        "event_start_time": "eventStartTime",
    }
)
class SpecialBet(BaseModel):
    """SpecialBet

    :param bet_id: Bet identification
    :type bet_id: int
    :param unique_request_id: Unique Request Id, defaults to None
    :type unique_request_id: str, optional
    :param wager_number: Wager identification. All bets placed thru the API will have value 1. Website Classic view supports multiple contest(special) bets placement in the same bet slip in that case the bet would have appropriate wager number, as well as all round robin parlay bets.
    :type wager_number: int
    :param placed_at: Date time when the bet was placed.
    :type placed_at: str
    :param bet_status: Bet Status. <br>ACCEPTED = Bet was accepted, <br>CANCELLED = Bet is cancelled as per Pinnacle betting rules, <br>LOSE = The bet is settled as lose,<br>REFUNDED = When an event is cancelled or when the bet is settled as push, the bet will have REFUNDED status, <br>WON = The bet is settled as won <br>PUSHED = The bet is settled as a push.<br>
    :type bet_status: SpecialBetBetStatus
    :param bet_type: bet_type
    :type bet_type: str
    :param win: Win amount.
    :type win: float
    :param risk: Risk amount.
    :type risk: float
    :param win_loss: Win-Loss for settled bets., defaults to None
    :type win_loss: float, optional
    :param odds_format: Bet odds format.  <br>AMERICAN = American odds format,  <br>DECIMAL = Decimal (European) odds format,  <br>HONGKONG = Hong Kong odds format,  <br>INDONESIAN = Indonesian odds format,  <br>MALAY = Malaysian odds format <br>
    :type odds_format: OddsFormat
    :param customer_commission: Client’s commission on the bet., defaults to None
    :type customer_commission: float, optional
    :param cancellation_reason: Possible keys \:  <br>* correctTeam1Id<br>* correctTeam2Id<br>* correctListedPitcher1<br>* correctListedPitcher2<br>* correctSpread<br>* correctTotalPoints<br>* correctTeam1TotalPoints<br>* correctTeam2TotalPoints<br>* correctTeam1Score<br>* correctTeam2Score<br>* correctTeam1TennisSetsScore<br>* correctTeam2TennisSetsScore<br>, defaults to None
    :type cancellation_reason: CancellationReason, optional
    :param update_sequence: Update Sequence. It gets updated when the bet status change.
    :type update_sequence: int
    :param special_id: special_id
    :type special_id: int
    :param special_name: special_name
    :type special_name: str
    :param contestant_id: contestant_id
    :type contestant_id: int
    :param contestant_name: contestant_name
    :type contestant_name: str
    :param price: price
    :type price: float
    :param handicap: handicap, defaults to None
    :type handicap: float, optional
    :param units: units, defaults to None
    :type units: str, optional
    :param sport_id: sport_id
    :type sport_id: int
    :param league_id: league_id
    :type league_id: int
    :param event_id: Populated if bet was placed on a special linked to the event., defaults to None
    :type event_id: int, optional
    :param period_number: Populated if bet was placed on a special linked to the event., defaults to None
    :type period_number: int, optional
    :param team1: Populated if bet was placed on a special linked to the event., defaults to None
    :type team1: str, optional
    :param team2: Populated if bet was placed on a special linked to the event., defaults to None
    :type team2: str, optional
    :param event_start_time: Date time when the event starts, defaults to None
    :type event_start_time: str, optional
    """

    def __init__(
        self,
        bet_id: int,
        wager_number: int,
        placed_at: str,
        bet_status: SpecialBetBetStatus,
        bet_type: str,
        win: float,
        risk: float,
        odds_format: OddsFormat,
        update_sequence: int,
        special_id: int,
        special_name: str,
        contestant_id: int,
        contestant_name: str,
        price: float,
        sport_id: int,
        league_id: int,
        unique_request_id: str = None,
        win_loss: float = None,
        customer_commission: float = None,
        cancellation_reason: CancellationReason = None,
        handicap: float = None,
        units: str = None,
        event_id: int = None,
        period_number: int = None,
        team1: str = None,
        team2: str = None,
        event_start_time: str = None,
    ):
        self.bet_id = bet_id
        if unique_request_id is not None:
            self.unique_request_id = unique_request_id
        self.wager_number = wager_number
        self.placed_at = placed_at
        self.bet_status = self._enum_matching(
            bet_status, SpecialBetBetStatus.list(), "bet_status"
        )
        self.bet_type = bet_type
        self.win = win
        self.risk = risk
        if win_loss is not None:
            self.win_loss = win_loss
        self.odds_format = self._enum_matching(
            odds_format, OddsFormat.list(), "odds_format"
        )
        if customer_commission is not None:
            self.customer_commission = customer_commission
        if cancellation_reason is not None:
            self.cancellation_reason = self._define_object(
                cancellation_reason, CancellationReason
            )
        self.update_sequence = update_sequence
        self.special_id = special_id
        self.special_name = special_name
        self.contestant_id = contestant_id
        self.contestant_name = contestant_name
        self.price = price
        if handicap is not None:
            self.handicap = handicap
        if units is not None:
            self.units = units
        self.sport_id = sport_id
        self.league_id = league_id
        if event_id is not None:
            self.event_id = event_id
        if period_number is not None:
            self.period_number = period_number
        if team1 is not None:
            self.team1 = team1
        if team2 is not None:
            self.team2 = team2
        if event_start_time is not None:
            self.event_start_time = event_start_time



# This file was generated by liblab | https://liblab.com/

from enum import Enum
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel


class ParlayLegResponseStatus(Enum):
    """An enumeration representing different categories.

    :cvar PROCESSED_WITH_ERROR: "PROCESSED_WITH_ERROR"
    :vartype PROCESSED_WITH_ERROR: str
    :cvar VALID: "VALID"
    :vartype VALID: str
    """

    PROCESSED_WITH_ERROR = "PROCESSED_WITH_ERROR"
    VALID = "VALID"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, ParlayLegResponseStatus._member_map_.values())
        )


class ParlayLegResponseErrorCode(Enum):
    """An enumeration representing different categories.

    :cvar CANNOT_PARLAY_LIVE_GAME: "CANNOT_PARLAY_LIVE_GAME"
    :vartype CANNOT_PARLAY_LIVE_GAME: str
    :cvar CORRELATED: "CORRELATED"
    :vartype CORRELATED: str
    :cvar EVENT_NO_LONGER_AVAILABLE_FOR_BETTING: "EVENT_NO_LONGER_AVAILABLE_FOR_BETTING"
    :vartype EVENT_NO_LONGER_AVAILABLE_FOR_BETTING: str
    :cvar EVENT_NOT_OFFERED_FOR_PARLAY: "EVENT_NOT_OFFERED_FOR_PARLAY"
    :vartype EVENT_NOT_OFFERED_FOR_PARLAY: str
    :cvar INVALID_EVENT: "INVALID_EVENT"
    :vartype INVALID_EVENT: str
    :cvar INVALID_LEG_BET_TYPE: "INVALID_LEG_BET_TYPE"
    :vartype INVALID_LEG_BET_TYPE: str
    :cvar INVALID_PARLAY_BET: "INVALID_PARLAY_BET"
    :vartype INVALID_PARLAY_BET: str
    :cvar LINE_CHANGED: "LINE_CHANGED"
    :vartype LINE_CHANGED: str
    :cvar LINE_DOES_NOT_BELONG_TO_EVENT: "LINE_DOES_NOT_BELONG_TO_EVENT"
    :vartype LINE_DOES_NOT_BELONG_TO_EVENT: str
    :cvar ODDS_NO_LONGER_OFFERED_FOR_PARLAY_1: "ODDS_NO_LONGER_OFFERED_FOR_PARLAY_1"
    :vartype ODDS_NO_LONGER_OFFERED_FOR_PARLAY_1: str
    :cvar ODDS_NO_LONGER_OFFERED_FOR_PARLAY_2: "ODDS_NO_LONGER_OFFERED_FOR_PARLAY_2"
    :vartype ODDS_NO_LONGER_OFFERED_FOR_PARLAY_2: str
    :cvar ODDS_NO_LONGER_OFFERED_FOR_PARLAY_3: "ODDS_NO_LONGER_OFFERED_FOR_PARLAY_3"
    :vartype ODDS_NO_LONGER_OFFERED_FOR_PARLAY_3: str
    :cvar OFFLINE_EVENT: "OFFLINE_EVENT"
    :vartype OFFLINE_EVENT: str
    :cvar PAST_CUTOFFTIME: "PAST_CUTOFFTIME"
    :vartype PAST_CUTOFFTIME: str
    :cvar SYSTEM_ERROR_1: "SYSTEM_ERROR_1"
    :vartype SYSTEM_ERROR_1: str
    :cvar SYSTEM_ERROR_2: "SYSTEM_ERROR_2"
    :vartype SYSTEM_ERROR_2: str
    :cvar SYSTEM_ERROR_3: "SYSTEM_ERROR_3"
    :vartype SYSTEM_ERROR_3: str
    :cvar LINE_IS_NOT_AVAILABLE: "LINE_IS_NOT_AVAILABLE"
    :vartype LINE_IS_NOT_AVAILABLE: str
    :cvar PERIOD_IS_DISALLOWED_FOR_SAME_GAME_PARLAY: "PERIOD_IS_DISALLOWED_FOR_SAME_GAME_PARLAY"
    :vartype PERIOD_IS_DISALLOWED_FOR_SAME_GAME_PARLAY: str
    :cvar BETTING_SUSPENDED: "BETTING_SUSPENDED"
    :vartype BETTING_SUSPENDED: str
    """

    CANNOT_PARLAY_LIVE_GAME = "CANNOT_PARLAY_LIVE_GAME"
    CORRELATED = "CORRELATED"
    EVENT_NO_LONGER_AVAILABLE_FOR_BETTING = "EVENT_NO_LONGER_AVAILABLE_FOR_BETTING"
    EVENT_NOT_OFFERED_FOR_PARLAY = "EVENT_NOT_OFFERED_FOR_PARLAY"
    INVALID_EVENT = "INVALID_EVENT"
    INVALID_LEG_BET_TYPE = "INVALID_LEG_BET_TYPE"
    INVALID_PARLAY_BET = "INVALID_PARLAY_BET"
    LINE_CHANGED = "LINE_CHANGED"
    LINE_DOES_NOT_BELONG_TO_EVENT = "LINE_DOES_NOT_BELONG_TO_EVENT"
    ODDS_NO_LONGER_OFFERED_FOR_PARLAY_1 = "ODDS_NO_LONGER_OFFERED_FOR_PARLAY_1"
    ODDS_NO_LONGER_OFFERED_FOR_PARLAY_2 = "ODDS_NO_LONGER_OFFERED_FOR_PARLAY_2"
    ODDS_NO_LONGER_OFFERED_FOR_PARLAY_3 = "ODDS_NO_LONGER_OFFERED_FOR_PARLAY_3"
    OFFLINE_EVENT = "OFFLINE_EVENT"
    PAST_CUTOFFTIME = "PAST_CUTOFFTIME"
    SYSTEM_ERROR_1 = "SYSTEM_ERROR_1"
    SYSTEM_ERROR_2 = "SYSTEM_ERROR_2"
    SYSTEM_ERROR_3 = "SYSTEM_ERROR_3"
    LINE_IS_NOT_AVAILABLE = "LINE_IS_NOT_AVAILABLE"
    PERIOD_IS_DISALLOWED_FOR_SAME_GAME_PARLAY = (
        "PERIOD_IS_DISALLOWED_FOR_SAME_GAME_PARLAY"
    )
    BETTING_SUSPENDED = "BETTING_SUSPENDED"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, ParlayLegResponseErrorCode._member_map_.values())
        )


@JsonMap(
    {
        "error_code": "errorCode",
        "leg_id": "legId",
        "line_id": "lineId",
        "alt_line_id": "altLineId",
        "correlated_legs": "correlatedLegs",
    }
)
class ParlayLegResponse(BaseModel):
    """ParlayLegResponse

    :param status: Status of the request., defaults to None
    :type status: ParlayLegResponseStatus, optional
    :param error_code: When Status is PROCESSED_WITH_ERROR, provides a code indicating the specific problem.<br><br>CANNOT_PARLAY_LIVE_GAME = The wager is placed on Live game,  <br>CORRELATED = The leg is correlated with another one,  <br>EVENT_NO_LONGER_AVAILABLE_FOR_BETTING = The event is no longer offered,  <br>EVENT_NOT_OFFERED_FOR_PARLAY = The event is not offered for parlaying,  <br>INVALID_EVENT = Live betting is not allowed at this moment,  <br>INVALID_LEG_BET_TYPE = Leg bet type is not accepted for parlaying. Accepted values are SPREAD, MONEYLINE, TOTAL_POINTS,  <br>INVALID_PARLAY_BET = The leg did not validated due to error on Parlay Bet. Check the error PlaceParlayBet response for error details,  <br>LINE_CHANGED = Bet is submitted on a line that has changed,  <br>LINE_DOES_NOT_BELONG_TO_EVENT = LineId does not match the EventId specified in the request,  <br>LISTED_PITCHERS_SELECTION_ERROR = If bet was submitted with pitcher1MustStart and/or pitcher2MustStart parameters with values that are not allowed,  <br>ODDS_NO_LONGER_OFFERED_FOR_PARLAY_1 = Due to line change odds are not offered for parlaying,   <br>ODDS_NO_LONGER_OFFERED_FOR_PARLAY_2 = Due to line change odds are not offered for parlaying,   <br>ODDS_NO_LONGER_OFFERED_FOR_PARLAY_3 = Due to line change odds are not offered for parlaying,   <br>OFFLINE_EVENT = Bet is submitted on an event that is offline or with incorrect lineId,  <br>PAST_CUTOFFTIME = Bet is submitted on a game after the betting cutoff time,   <br>SYSTEM_ERROR_1 = Unexpected error,  <br>SYSTEM_ERROR_2 = Unexpected error,  <br>SYSTEM_ERROR_3 = Unexpected error,  <br>LINE_IS_NOT_AVAILABLE = Line is not available for the specified Parlay Leg,  <br>PERIOD_IS_DISALLOWED_FOR_SAME_GAME_PARLAY = Period is not allowed to be parlayed on a same event, <br>BETTING_SUSPENDED - Due to anomalous market circumstances bets are not currently being accepted on this line. Try again with next LineId.<br>, defaults to None
    :type error_code: ParlayLegResponseErrorCode, optional
    :param leg_id: Echo of the legId from the request., defaults to None
    :type leg_id: str, optional
    :param line_id: Line identification that bet was placed on., defaults to None
    :type line_id: int, optional
    :param alt_line_id: If bet was accepted on alternate line, the altLineId will be returned., defaults to None
    :type alt_line_id: int, optional
    :param price: Price that the bet was placed on., defaults to None
    :type price: float, optional
    :param correlated_legs: If errorCode is CORRELATED will contain legIds of all correlated legs., defaults to None
    :type correlated_legs: List[str], optional
    """

    def __init__(
        self,
        status: ParlayLegResponseStatus = None,
        error_code: ParlayLegResponseErrorCode = None,
        leg_id: str = None,
        line_id: int = None,
        alt_line_id: int = None,
        price: float = None,
        correlated_legs: List[str] = None,
    ):
        if status is not None:
            self.status = self._enum_matching(
                status, ParlayLegResponseStatus.list(), "status"
            )
        if error_code is not None:
            self.error_code = self._enum_matching(
                error_code, ParlayLegResponseErrorCode.list(), "error_code"
            )
        if leg_id is not None:
            self.leg_id = leg_id
        if line_id is not None:
            self.line_id = line_id
        if alt_line_id is not None:
            self.alt_line_id = alt_line_id
        if price is not None:
            self.price = price
        if correlated_legs is not None:
            self.correlated_legs = correlated_legs



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from enum import Enum
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .odds_format import OddsFormat
from .cancellation_reason import CancellationReason
from .teaser_leg import TeaserLeg


class TeaserBetBetStatus(Enum):
    """An enumeration representing different categories.

    :cvar ACCEPTED: "ACCEPTED"
    :vartype ACCEPTED: str
    :cvar CANCELLED: "CANCELLED"
    :vartype CANCELLED: str
    :cvar LOSE: "LOSE"
    :vartype LOSE: str
    :cvar REFUNDED: "REFUNDED"
    :vartype REFUNDED: str
    :cvar WON: "WON"
    :vartype WON: str
    """

    ACCEPTED = "ACCEPTED"
    CANCELLED = "CANCELLED"
    LOSE = "LOSE"
    REFUNDED = "REFUNDED"
    WON = "WON"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, TeaserBetBetStatus._member_map_.values()))


@JsonMap(
    {
        "bet_id": "betId",
        "unique_request_id": "uniqueRequestId",
        "wager_number": "wagerNumber",
        "placed_at": "placedAt",
        "bet_status": "betStatus",
        "bet_type": "betType",
        "win_loss": "winLoss",
        "odds_format": "oddsFormat",
        "customer_commission": "customerCommission",
        "cancellation_reason": "cancellationReason",
        "update_sequence": "updateSequence",
        "teaser_name": "teaserName",
        "is_same_event_only": "isSameEventOnly",
        "min_picks": "minPicks",
        "max_picks": "maxPicks",
        "final_price": "finalPrice",
        "teaser_id": "teaserId",
        "teaser_group_id": "teaserGroupId",
    }
)
class TeaserBet(BaseModel):
    """TeaserBet

    :param bet_id: Bet identification
    :type bet_id: int
    :param unique_request_id: Unique Request Id, defaults to None
    :type unique_request_id: str, optional
    :param wager_number: Wager identification. All bets placed thru the API will have value 1. Website Classic view supports multiple contest(special) bets placement in the same bet slip in that case the bet would have appropriate wager number, as well as all round robin parlay bets.
    :type wager_number: int
    :param placed_at: Date time when the bet was placed.
    :type placed_at: str
    :param bet_status: Bet Status. <br><br>ACCEPTED = Bet was accepted,  <br>CANCELLED = Bet is cancelled as per Pinnacle betting rules,  <br>LOSE = The bet is settled as lose,  <br>REFUNDED = When an event is cancelled or when the bet is settled as push, the bet will have REFUNDED status,  <br>WON = The bet is settled as won <br>
    :type bet_status: TeaserBetBetStatus
    :param bet_type: bet_type
    :type bet_type: str
    :param win: Win amount.
    :type win: float
    :param risk: Risk amount.
    :type risk: float
    :param win_loss: Win-Loss for settled bets., defaults to None
    :type win_loss: float, optional
    :param odds_format: Bet odds format.  <br>AMERICAN = American odds format,  <br>DECIMAL = Decimal (European) odds format,  <br>HONGKONG = Hong Kong odds format,  <br>INDONESIAN = Indonesian odds format,  <br>MALAY = Malaysian odds format <br>
    :type odds_format: OddsFormat
    :param customer_commission: Client’s commission on the bet., defaults to None
    :type customer_commission: float, optional
    :param cancellation_reason: Possible keys \:  <br>* correctTeam1Id<br>* correctTeam2Id<br>* correctListedPitcher1<br>* correctListedPitcher2<br>* correctSpread<br>* correctTotalPoints<br>* correctTeam1TotalPoints<br>* correctTeam2TotalPoints<br>* correctTeam1Score<br>* correctTeam2Score<br>* correctTeam1TennisSetsScore<br>* correctTeam2TennisSetsScore<br>, defaults to None
    :type cancellation_reason: CancellationReason, optional
    :param update_sequence: Update Sequence
    :type update_sequence: int
    :param teaser_name: teaser_name
    :type teaser_name: str
    :param is_same_event_only: is_same_event_only
    :type is_same_event_only: bool
    :param min_picks: min_picks
    :type min_picks: float
    :param max_picks: max_picks
    :type max_picks: float
    :param price: Populated for all teaser bets and will be the original price at the time of the placement., defaults to None
    :type price: float, optional
    :param final_price: Only for settled parlay. Final price may differ in case leg was cancelled or half won., defaults to None
    :type final_price: float, optional
    :param teaser_id: Reference to the teaser id, defaults to None
    :type teaser_id: float, optional
    :param teaser_group_id: Reference to the teaser group id, defaults to None
    :type teaser_group_id: float, optional
    :param legs: legs
    :type legs: List[TeaserLeg]
    """

    def __init__(
        self,
        bet_id: int,
        wager_number: int,
        placed_at: str,
        bet_status: TeaserBetBetStatus,
        bet_type: str,
        win: float,
        risk: float,
        odds_format: OddsFormat,
        update_sequence: int,
        teaser_name: str,
        is_same_event_only: bool,
        min_picks: float,
        max_picks: float,
        legs: List[TeaserLeg],
        unique_request_id: str = None,
        win_loss: float = None,
        customer_commission: float = None,
        cancellation_reason: CancellationReason = None,
        price: float = None,
        final_price: float = None,
        teaser_id: float = None,
        teaser_group_id: float = None,
    ):
        self.bet_id = bet_id
        if unique_request_id is not None:
            self.unique_request_id = unique_request_id
        self.wager_number = wager_number
        self.placed_at = placed_at
        self.bet_status = self._enum_matching(
            bet_status, TeaserBetBetStatus.list(), "bet_status"
        )
        self.bet_type = bet_type
        self.win = win
        self.risk = risk
        if win_loss is not None:
            self.win_loss = win_loss
        self.odds_format = self._enum_matching(
            odds_format, OddsFormat.list(), "odds_format"
        )
        if customer_commission is not None:
            self.customer_commission = customer_commission
        if cancellation_reason is not None:
            self.cancellation_reason = self._define_object(
                cancellation_reason, CancellationReason
            )
        self.update_sequence = update_sequence
        self.teaser_name = teaser_name
        self.is_same_event_only = is_same_event_only
        self.min_picks = min_picks
        self.max_picks = max_picks
        if price is not None:
            self.price = price
        if final_price is not None:
            self.final_price = final_price
        if teaser_id is not None:
            self.teaser_id = teaser_id
        if teaser_group_id is not None:
            self.teaser_group_id = teaser_group_id
        self.legs = self._define_list(legs, TeaserLeg)



# This file was generated by liblab | https://liblab.com/

from enum import Enum
from .utils.json_map import JsonMap
from .base import BaseModel


class PlaceTeaserBetLegResponseErrorCode(Enum):
    """An enumeration representing different categories.

    :cvar CANNOT_TEASER_LIVE_GAME: "CANNOT_TEASER_LIVE_GAME"
    :vartype CANNOT_TEASER_LIVE_GAME: str
    :cvar CHECK_TEASER_ERROR: "CHECK_TEASER_ERROR"
    :vartype CHECK_TEASER_ERROR: str
    :cvar INVALID_EVENT: "INVALID_EVENT"
    :vartype INVALID_EVENT: str
    :cvar INVALID_LEG_BET: "INVALID_LEG_BET"
    :vartype INVALID_LEG_BET: str
    :cvar INVALID_LEG_BET_TYPE: "INVALID_LEG_BET_TYPE"
    :vartype INVALID_LEG_BET_TYPE: str
    :cvar LINE_CHANGED: "LINE_CHANGED"
    :vartype LINE_CHANGED: str
    :cvar LINE_DOES_NOT_BELONG_TO_EVENT: "LINE_DOES_NOT_BELONG_TO_EVENT"
    :vartype LINE_DOES_NOT_BELONG_TO_EVENT: str
    :cvar OFFLINE_EVENT: "OFFLINE_EVENT"
    :vartype OFFLINE_EVENT: str
    :cvar PAST_CUTOFFTIME: "PAST_CUTOFFTIME"
    :vartype PAST_CUTOFFTIME: str
    :cvar POINTS_ARE_NOT_ADJUSTED: "POINTS_ARE_NOT_ADJUSTED"
    :vartype POINTS_ARE_NOT_ADJUSTED: str
    :cvar SYSTEM_ERROR_1: "SYSTEM_ERROR_1"
    :vartype SYSTEM_ERROR_1: str
    :cvar SYSTEM_ERROR_2: "SYSTEM_ERROR_2"
    :vartype SYSTEM_ERROR_2: str
    :cvar WAGER_DATA_MISSING: "WAGER_DATA_MISSING"
    :vartype WAGER_DATA_MISSING: str
    :cvar LINE_IS_NOT_AVAILABLE: "LINE_IS_NOT_AVAILABLE"
    :vartype LINE_IS_NOT_AVAILABLE: str
    :cvar TEASER_IS_NOT_ENABLED: "TEASER_IS_NOT_ENABLED"
    :vartype TEASER_IS_NOT_ENABLED: str
    :cvar BETTING_SUSPENDED: "BETTING_SUSPENDED"
    :vartype BETTING_SUSPENDED: str
    """

    CANNOT_TEASER_LIVE_GAME = "CANNOT_TEASER_LIVE_GAME"
    CHECK_TEASER_ERROR = "CHECK_TEASER_ERROR"
    INVALID_EVENT = "INVALID_EVENT"
    INVALID_LEG_BET = "INVALID_LEG_BET"
    INVALID_LEG_BET_TYPE = "INVALID_LEG_BET_TYPE"
    LINE_CHANGED = "LINE_CHANGED"
    LINE_DOES_NOT_BELONG_TO_EVENT = "LINE_DOES_NOT_BELONG_TO_EVENT"
    OFFLINE_EVENT = "OFFLINE_EVENT"
    PAST_CUTOFFTIME = "PAST_CUTOFFTIME"
    POINTS_ARE_NOT_ADJUSTED = "POINTS_ARE_NOT_ADJUSTED"
    SYSTEM_ERROR_1 = "SYSTEM_ERROR_1"
    SYSTEM_ERROR_2 = "SYSTEM_ERROR_2"
    WAGER_DATA_MISSING = "WAGER_DATA_MISSING"
    LINE_IS_NOT_AVAILABLE = "LINE_IS_NOT_AVAILABLE"
    TEASER_IS_NOT_ENABLED = "TEASER_IS_NOT_ENABLED"
    BETTING_SUSPENDED = "BETTING_SUSPENDED"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value,
                PlaceTeaserBetLegResponseErrorCode._member_map_.values(),
            )
        )


@JsonMap({"error_code": "errorCode", "leg_id": "legId", "line_id": "lineId"})
class PlaceTeaserBetLegResponse(BaseModel):
    """PlaceTeaserBetLegResponse

    :param status: Status of the request., defaults to None
    :type status: str, optional
    :param error_code: When Status is PROCESSED_WITH_ERROR, provides a code indicating the specific problem.<br><br>CANNOT_TEASER_LIVE_GAME = Teaser is not allowed on a live game,   <br>CHECK_TEASER_ERROR = The teaser is invalid, check the teaser error for more details,  <br>INVALID_EVENT = The game is not found in the system,  <br>INVALID_LEG_BET = The wager is not verified,  <br>INVALID_LEG_BET_TYPE = Wager type is not “teasable”, can be either Spread or Total,  <br>LINE_CHANGED = Wager is placed on a line that has changed,  <br>LINE_DOES_NOT_BELONG_TO_EVENT = There was no game found for the wager,  <br>OFFLINE_EVENT = Either the game is offline OR there was no game found for the wager,  <br>PAST_CUTOFFTIME = Wager is placed on a game after the cutoff time,  <br>POINTS_ARE_NOT_ADJUSTED = The teaser points were not adjusted,  <br>SYSTEM_ERROR_1 = System error,  <br>SYSTEM_ERROR_2 = System error,  <br>WAGER_DATA_MISSING = Wager is denied due to insufficient information available for validation,  <br>LINE_IS_NOT_AVAILABLE = Line is not available for the specified Teaser Leg, <br>TEASER_IS_NOT_ENABLED = Teaser is not available for the specified leg, <br>BETTING_SUSPENDED - Due to anomalous market circumstances bets are not currently being accepted on this line. Try again with next LineId.<br>, defaults to None
    :type error_code: PlaceTeaserBetLegResponseErrorCode, optional
    :param leg_id: Echo of the legId from the request., defaults to None
    :type leg_id: str, optional
    :param line_id: Line identification that bet was placed on., defaults to None
    :type line_id: int, optional
    :param points: Number of points., defaults to None
    :type points: float, optional
    """

    def __init__(
        self,
        status: str = None,
        error_code: PlaceTeaserBetLegResponseErrorCode = None,
        leg_id: str = None,
        line_id: int = None,
        points: float = None,
    ):
        if status is not None:
            self.status = status
        if error_code is not None:
            self.error_code = self._enum_matching(
                error_code, PlaceTeaserBetLegResponseErrorCode.list(), "error_code"
            )
        if leg_id is not None:
            self.leg_id = leg_id
        if line_id is not None:
            self.line_id = line_id
        if points is not None:
            self.points = points



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .straight_bet_v4 import StraightBetV4
from .parlay_bet import ParlayBet
from .teaser_bet import TeaserBet
from .special_bet import SpecialBet
from .manual_bet import ManualBet


@JsonMap(
    {
        "more_available": "moreAvailable",
        "page_size": "pageSize",
        "from_record": "fromRecord",
        "to_record": "toRecord",
        "straight_bets": "straightBets",
        "parlay_bets": "parlayBets",
        "teaser_bets": "teaserBets",
        "special_bets": "specialBets",
        "manual_bets": "manualBets",
    }
)
class GetBetsByTypeResponseV4(BaseModel):
    """GetBetsByTypeResponseV4

    :param more_available: Whether there are more pages available., defaults to None
    :type more_available: bool, optional
    :param page_size: Page size. Default is 1000., defaults to None
    :type page_size: int, optional
    :param from_record: Starting record number of the result set. Records start at zero, defaults to None
    :type from_record: int, optional
    :param to_record: Ending record number of the result set., defaults to None
    :type to_record: int, optional
    :param straight_bets: A collection of placed straight bets., defaults to None
    :type straight_bets: List[StraightBetV4], optional
    :param parlay_bets: A collection of placed parlay bets., defaults to None
    :type parlay_bets: List[ParlayBet], optional
    :param teaser_bets: A collection of placed teaser bets., defaults to None
    :type teaser_bets: List[TeaserBet], optional
    :param special_bets: A collection of placed special bets., defaults to None
    :type special_bets: List[SpecialBet], optional
    :param manual_bets: A collection of placed manual bets., defaults to None
    :type manual_bets: List[ManualBet], optional
    """

    def __init__(
        self,
        more_available: bool = None,
        page_size: int = None,
        from_record: int = None,
        to_record: int = None,
        straight_bets: List[StraightBetV4] = None,
        parlay_bets: List[ParlayBet] = None,
        teaser_bets: List[TeaserBet] = None,
        special_bets: List[SpecialBet] = None,
        manual_bets: List[ManualBet] = None,
    ):
        if more_available is not None:
            self.more_available = more_available
        if page_size is not None:
            self.page_size = page_size
        if from_record is not None:
            self.from_record = from_record
        if to_record is not None:
            self.to_record = to_record
        if straight_bets is not None:
            self.straight_bets = self._define_list(straight_bets, StraightBetV4)
        if parlay_bets is not None:
            self.parlay_bets = self._define_list(parlay_bets, ParlayBet)
        if teaser_bets is not None:
            self.teaser_bets = self._define_list(teaser_bets, TeaserBet)
        if special_bets is not None:
            self.special_bets = self._define_list(special_bets, SpecialBet)
        if manual_bets is not None:
            self.manual_bets = self._define_list(manual_bets, ManualBet)



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from enum import Enum
from .utils.json_map import JsonMap
from .base import BaseModel
from .odds_format import OddsFormat


class SpecialBetRequestWinRiskStake(Enum):
    """An enumeration representing different categories.

    :cvar WIN: "WIN"
    :vartype WIN: str
    :cvar RISK: "RISK"
    :vartype RISK: str
    """

    WIN = "WIN"
    RISK = "RISK"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, SpecialBetRequestWinRiskStake._member_map_.values())
        )


@JsonMap(
    {
        "unique_request_id": "uniqueRequestId",
        "accept_better_line": "acceptBetterLine",
        "odds_format": "oddsFormat",
        "win_risk_stake": "winRiskStake",
        "line_id": "lineId",
        "special_id": "specialId",
        "contestant_id": "contestantId",
    }
)
class SpecialBetRequest(BaseModel):
    """SpecialBetRequest

    :param unique_request_id: This unique id of the place bet requests. This is to support idempotent requests., defaults to None
    :type unique_request_id: str, optional
    :param accept_better_line: Whether or not to accept a bet when there is a line change in favor of the client., defaults to None
    :type accept_better_line: bool, optional
    :param odds_format: Bet odds format.  <br>AMERICAN = American odds format,  <br>DECIMAL = Decimal (European) odds format,  <br>HONGKONG = Hong Kong odds format,  <br>INDONESIAN = Indonesian odds format,  <br>MALAY = Malaysian odds format <br>, defaults to None
    :type odds_format: OddsFormat, optional
    :param stake: amount in client’s currency., defaults to None
    :type stake: float, optional
    :param win_risk_stake: Whether the stake amount is risk or win amount., defaults to None
    :type win_risk_stake: SpecialBetRequestWinRiskStake, optional
    :param line_id: Line identification., defaults to None
    :type line_id: int, optional
    :param special_id: Special identification., defaults to None
    :type special_id: int, optional
    :param contestant_id: Contestant identification., defaults to None
    :type contestant_id: int, optional
    """

    def __init__(
        self,
        unique_request_id: str = None,
        accept_better_line: bool = None,
        odds_format: OddsFormat = None,
        stake: float = None,
        win_risk_stake: SpecialBetRequestWinRiskStake = None,
        line_id: int = None,
        special_id: int = None,
        contestant_id: int = None,
    ):
        if unique_request_id is not None:
            self.unique_request_id = unique_request_id
        if accept_better_line is not None:
            self.accept_better_line = accept_better_line
        if odds_format is not None:
            self.odds_format = self._enum_matching(
                odds_format, OddsFormat.list(), "odds_format"
            )
        if stake is not None:
            self.stake = stake
        if win_risk_stake is not None:
            self.win_risk_stake = self._enum_matching(
                win_risk_stake, SpecialBetRequestWinRiskStake.list(), "win_risk_stake"
            )
        if line_id is not None:
            self.line_id = line_id
        if special_id is not None:
            self.special_id = special_id
        if contestant_id is not None:
            self.contestant_id = contestant_id



# This file was generated by liblab | https://liblab.com/

from .services.place_bets import PlaceBetsService
from .services.get_bets import GetBetsService
from .services.betting_status import BettingStatusService
from .net.environment import Environment


class Pinnacle:
    def __init__(
        self,
        username: str = None,
        password: str = None,
        base_url: str = Environment.DEFAULT.value,
    ):
        """
        Initializes Pinnacle the SDK class.
        """
        self.place_bets = PlaceBetsService(base_url=base_url)
        self.get_bets = GetBetsService(base_url=base_url)
        self.betting_status = BettingStatusService(base_url=base_url)
        self.set_basic_auth(username=username, password=password)

    def set_base_url(self, base_url):
        """
        Sets the base URL for the entire SDK.
        """
        self.place_bets.set_base_url(base_url)
        self.get_bets.set_base_url(base_url)
        self.betting_status.set_base_url(base_url)

        return self

    def set_basic_auth(self, username: str, password: str):
        """
        Sets the username and password for the entire SDK.
        """
        self.place_bets.set_basic_auth(username=username, password=password)
        self.get_bets.set_basic_auth(username=username, password=password)
        self.betting_status.set_basic_auth(username=username, password=password)

        return self


# c029837e0e474b76bc487506e8799df5e3335891efe4fb02bda7a1441840310c
